@@ -27,6 +27,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "Util/FileSystem.hpp"
 #include "Util/Exception.hpp"
 #include "Util/UtilInterface.hpp"
+#include "Util/Endian.hpp"
 #include "PackedSurface.hpp"
 #include "Surface.hpp"
 #include "Span.hpp"
@@ -109,9 +110,10 @@ void PackedSurface::pack(const Surface &source)
 {
     free();
 
-    pix        = source.getPix();
+    pix.x      = source.getWidth();
+    pix.y      = source.getHeight();
     offset     = source.getOffset();
-    frameCount = source.getFrameCount();
+    frameCount = source.getNumFrames();
     fps        = source.getFPS();
 
     rowOffsetTable = (int *) malloc((pix.y*frameCount + 1) * sizeof(*rowOffsetTable));
@@ -129,7 +131,7 @@ void PackedSurface::pack(const Surface &source)
         ((Surface *)&source)->setFrame(frame);
         for (int y = 0 ; y < pix.y ; ++y) {
             rowOffsetTable[frame*pix.y + y] = curByteOffset;
-            const PIX *rowPtr = source.rowPtr(y);
+            const PIX *rowPtr = source.pixPtr(0,y);
 
             int x = 0;
             while (x < pix.x) {
@@ -155,7 +157,7 @@ void PackedSurface::pack(const Surface &source)
                 int newSize = (curByteOffset + sizeof(SpanHead) + spanLen*sizeof(PIX) + 3) & ~3;
                 if (newSize > bytesAlloced) {
                     bytesAlloced = newSize + 16*1024;
-                    packedDataChunk = (uint8_t *)realloc(packedDataChunk, bytesAlloced);
+                    packedDataChunk = (Uint8 *)realloc(packedDataChunk, bytesAlloced);
                     if (packedDataChunk == 0) {
                         throw Exception("ERROR: Out of memory for packedDataChunk for PackedSurface.");
                     }
@@ -164,8 +166,8 @@ void PackedSurface::pack(const Surface &source)
                 // Now write the data into the chunk.
 
                 SpanHead *span = (SpanHead *)(packedDataChunk + curByteOffset);
-                span->x1 = spanX1;
-                span->len = spanLen;
+                span->x1 = htol16(spanX1);
+                span->len = htol16(spanLen);
                 memcpy(span + 1, &rowPtr[spanX1], spanLen * sizeof(PIX));
                 curByteOffset = newSize;
             }
@@ -179,7 +181,7 @@ void PackedSurface::pack(const Surface &source)
 
     // Shrink buffer to the size we really need
 
-    packedDataChunk = (uint8_t *) realloc(packedDataChunk, curByteOffset);
+    packedDataChunk = (Uint8 *) realloc(packedDataChunk, curByteOffset);
     if (packedDataChunk == 0) throw Exception("Hell froze");
 
     // Restore source surface frame number, so the function
@@ -189,77 +191,88 @@ void PackedSurface::pack(const Surface &source)
 }
 
 //--------------------------------------------------------------------------
-void PackedSurface::load(const char* filename)
+void PackedSurface::load(const std::string& filename)
 {
-    std::auto_ptr<ReadFile> file (FileSystem::openRead(filename));
+    try {
+	std::auto_ptr<filesystem::ReadFile> file(
+                filesystem::openRead(filename));
 
-    free();
-    int32_t version = file->readSLE32();
-    if (version < 1)
-        throw Exception("Invalid PAK file version: %d", version);
-    if (version > CURRENT_PAK_VERSION)
-        throw Exception("PAK file version of '%s' is newer(%d) than "
-                "the currently supported version(%d)",
-		filename, version, CURRENT_PAK_VERSION);
-    pix.x = file->readSLE32();
-    pix.y = file->readSLE32();
+	free();
+	Sint32 version = file->readSLE32();
+	if (version < 1)
+	    throw Exception("Invalid PAK file version: %d", version);
+	if (version > CURRENT_PAK_VERSION)
+	    throw Exception("PAK file version of '%s' is newer(%d) than "
+		    "the currently supported version(%d)",
+		filename.c_str(), version, CURRENT_PAK_VERSION);
+	pix.x = file->readSLE32();
+	pix.y = file->readSLE32();
 
-    center = pix / 2;
+	center = pix / 2;
 
-    frameCount = file->readSLE32(); 
-    // should be done like following but this isn't backward compatible to the
-    // existing files :-/
-    //fps = float(file->readSLE32()) / 65536;
-    // XXX is this correct?!?
-    int32_t fpsint = file->readSLE32();
-    fps = * ((float*) &fpsint);
-    offset.x = file->readSLE32();
-    offset.y = file->readSLE32();
+	frameCount = file->readSLE32(); 
+	// should be done like following but this isn't backward compatible to
+	// the existing files :-/
+	//fps = float(file->readSLE32()) / 65536;
+	// XXX is this correct?!?
+	Sint32 fpsint = file->readSLE32();
+	fps = * ((float*) (void*) &fpsint);
+	offset.x = file->readSLE32();
+	offset.y = file->readSLE32();
     
-    rowOffsetTable = (int *) malloc((pix.y * frameCount + 1) * sizeof(*rowOffsetTable));
-    if (rowOffsetTable == 0)
-        throw Exception("ERROR: Unable to allocate rowTableOffset for PackedSurface.");
-    for(int i=0;i<(pix.y * frameCount+1);i++) {
-        rowOffsetTable[i] = file->readSLE32();
-    }
+	rowOffsetTable = (int *) malloc((pix.y * frameCount + 1) * sizeof(*rowOffsetTable));
+	if (rowOffsetTable == 0)
+	    throw Exception(
+		"ERROR: Unable to allocate rowTableOffset for PackedSurface.");
+	for(int i=0;i<(pix.y * frameCount+1);i++) {
+	    rowOffsetTable[i] = file->readSLE32();
+	}
     
-    packedDataChunk = (uint8_t *)malloc(rowOffsetTable[pix.y*frameCount]);
-    if (packedDataChunk == 0) {
-        throw Exception("ERROR: Unable to allocate packedDataChunk for PackedSurface.");
+	packedDataChunk = (Uint8 *)malloc(rowOffsetTable[pix.y*frameCount]);
+	if (packedDataChunk == 0) {
+	    throw Exception(
+		"ERROR: Unable to allocate packedDataChunk for PackedSurface.");
+	}
+	file->read(packedDataChunk, rowOffsetTable[pix.y*frameCount], 1);
+
+	// Add size of rowTableOffset.
+	totalByteCount += (pix.y * frameCount + 1) * sizeof(*rowOffsetTable);
+
+	// Add size of packedDataChunk.
+	totalByteCount += pix.y * frameCount;
+    } catch(std::exception& e) {
+	throw Exception("Error while reading pakfile '%s': %s",
+	    filename.c_str(), e.what());
     }
-    if(file->read(packedDataChunk, rowOffsetTable[pix.y*frameCount], 1) != 1)
-        throw Exception("error while reading %s.", filename);
-
-    // Add size of rowTableOffset.
-    totalByteCount += (pix.y * frameCount + 1) * sizeof(*rowOffsetTable);
-
-    // Add size of packedDataChunk.
-    totalByteCount += pix.y * frameCount;
 }
 
 //--------------------------------------------------------------------------
-void PackedSurface::save(const char* filename) const
+void PackedSurface::save(const std::string& filename) const
 {
-    std::auto_ptr<WriteFile> file (FileSystem::openWrite(filename));
+    try {
+	std::auto_ptr<filesystem::WriteFile> file(
+                filesystem::openWrite(filename));
 
-    int32_t version = CURRENT_PAK_VERSION;
-    file->writeSLE32(version);
-    file->writeSLE32(pix.x);
-    file->writeSLE32(pix.y);
+	Sint32 version = CURRENT_PAK_VERSION;
+	file->writeSLE32(version);
+	file->writeSLE32(pix.x);
+	file->writeSLE32(pix.y);
     
-    // XXX bad not endian safe :-/
-    // is this correct?!?
-    file->writeSLE32( *((uint32_t*) (&fps)) );
+	// is this correct?!?
+	file->writeSLE32( *((Uint32*) (void*) (&fps)) );
 
-    file->writeSLE32(offset.x);
-    file->writeSLE32(offset.y);
+	file->writeSLE32(offset.x);
+	file->writeSLE32(offset.y);
     
-    for(int i=0;i<(pix.y*frameCount+1); i++) {
-        file->writeSLE32(rowOffsetTable[i]);
+	for(int i=0;i<(pix.y*frameCount+1); i++) {
+	    file->writeSLE32(rowOffsetTable[i]);
+	}
+    
+	file->write(packedDataChunk, rowOffsetTable[pix.y*frameCount], 1);
+    } catch(std::exception& e) {
+	throw Exception("Error while writing pakfile '%s': %s",
+		filename.c_str(), e.what());
     }
-    
-    if (file->write(packedDataChunk, rowOffsetTable[pix.y*frameCount], 1) != 1)
-        throw Exception("error while writing '%s'.", filename);
 }
 
 //--------------------------------------------------------------------------
@@ -275,9 +288,9 @@ void PackedSurface::blt(Surface &dest, int destX, int destY) const
     int needClipX = 0;
 
     iXY srcMax;
-    srcMax.x = dest.getPixX() - destX;
+    srcMax.x = dest.getWidth() - destX;
     if (srcMax.x <= 0) return; // off right
-    srcMax.y = dest.getPixY() - destY;
+    srcMax.y = dest.getHeight() - destY;
     if (srcMax.y <= 0) return; // off bottom
 
     iXY srcMin;
@@ -307,11 +320,11 @@ void PackedSurface::blt(Surface &dest, int destX, int destY) const
     const int *table = &rowOffsetTable[int(curFrame)*pix.y];
 
     if (needClipX) {
-        const uint8_t *rowData = packedDataChunk + table[srcMin.y];
-        PIX *destRowPtr = dest.rowPtr(destY + srcMin.y) + destX;
+        const Uint8 *rowData = packedDataChunk + table[srcMin.y];
+        PIX *destRowPtr = dest.pixPtr(0, destY + srcMin.y) + destX;
         for (int y = srcMin.y ; y < srcMax.y ; ++y) {
 
-            const uint8_t *rowEnd = packedDataChunk + table[y+1];
+            const Uint8 *rowEnd = packedDataChunk + table[y+1];
 
             // Search for first span which is not completely off to the left
 
@@ -321,9 +334,9 @@ void PackedSurface::blt(Surface &dest, int destX, int destY) const
             for (;;) {
                 if (rowData >= rowEnd) goto nextRow;
                 span = (SpanHead *)rowData;
-                x1 = span->x1;
-                x2 = x1 + span->len;
-                rowData += (sizeof(*span) + span->len*sizeof(PIX) + 3) & ~3;
+                x1 = ltoh16(span->x1);
+                x2 = x1 + ltoh16(span->len);
+                rowData += (sizeof(*span) + ltoh16(span->len)*sizeof(PIX) + 3) & ~3;
                 if (x2 > srcMin.x) break;
             }
 
@@ -356,34 +369,35 @@ void PackedSurface::blt(Surface &dest, int destX, int destY) const
 
                 if (rowData >= rowEnd) goto nextRow;
                 span = (SpanHead *)rowData;
-                x1 = span->x1;
+                x1 = ltoh16(span->x1);
                 if (x1 >= srcMax.x) {
                     rowData = rowEnd;
                     goto nextRow;
                 }
-                x2 = x1 + span->len;
+                x2 = x1 + ltoh16(span->len);
                 data = (const PIX *)(span + 1);
-                rowData += (sizeof(*span) + span->len*sizeof(PIX) + 3) & ~3;
+                rowData += (sizeof(*span) + ltoh16(span->len)*sizeof(PIX) + 3) & ~3;
             }
 
 nextRow:
             assert(rowData == rowEnd);
-            destRowPtr += dest.getStride();
+            destRowPtr += dest.getPitch();
         }
     } else {
-        const uint8_t *rowData = packedDataChunk + table[srcMin.y];
-        PIX *destRowPtr = dest.rowPtr(destY + srcMin.y) + destX;
+        const Uint8 *rowData = packedDataChunk + table[srcMin.y];
+        PIX *destRowPtr = dest.pixPtr(0,destY + srcMin.y) + destX;
         for (int y = srcMin.y ; y < srcMax.y ; ++y) {
 
-            const uint8_t *rowEnd = packedDataChunk + table[y+1];
+            const Uint8 *rowEnd = packedDataChunk + table[y+1];
 
             while (rowData < rowEnd) {
                 SpanHead *span = (SpanHead *)rowData;
-                memcpy(destRowPtr + span->x1, span + 1, span->len * sizeof(PIX));
-                rowData += (sizeof(*span) + span->len*sizeof(PIX) + 3) & ~3;
+                memcpy(destRowPtr + ltoh16(span->x1), span + 1,
+                    ltoh16(span->len) * sizeof(PIX));
+                rowData += (sizeof(*span) + ltoh16(span->len)*sizeof(PIX) + 3) & ~3;
             }
             assert(rowData == rowEnd);
-            destRowPtr += dest.getStride();
+            destRowPtr += dest.getPitch();
         }
     }
 
@@ -443,9 +457,9 @@ void PackedSurface::bltBlend(Surface &dest, int destX, int destY, ColorTable &co
     int needClipX = 0;
 
     iXY srcMax;
-    srcMax.x = dest.getPixX() - destX;
+    srcMax.x = dest.getWidth() - destX;
     if (srcMax.x <= 0) return; // off right
-    srcMax.y = dest.getPixY() - destY;
+    srcMax.y = dest.getHeight() - destY;
     if (srcMax.y <= 0) return; // off bottom
 
     iXY srcMin;
@@ -472,15 +486,15 @@ void PackedSurface::bltBlend(Surface &dest, int destX, int destY, ColorTable &co
         srcMax.y = pix.y;
     }
 
-    const uint8_t *cTable = colorTable.getColorArray();
+    const Uint8 *cTable = colorTable.getColorArray();
     const int  *table  = &rowOffsetTable[int(curFrame)*pix.y];
 
     if (needClipX) {
-        const uint8_t *rowData = packedDataChunk + table[srcMin.y];
-        PIX *destRowPtr = dest.rowPtr(destY + srcMin.y) + destX;
+        const Uint8 *rowData = packedDataChunk + table[srcMin.y];
+        PIX *destRowPtr = dest.pixPtr(0, destY + srcMin.y) + destX;
         for (int y = srcMin.y ; y < srcMax.y ; ++y) {
 
-            const uint8_t *rowEnd = packedDataChunk + table[y+1];
+            const Uint8 *rowEnd = packedDataChunk + table[y+1];
 
             // Search for first span which is not completely off to the left
 
@@ -490,9 +504,9 @@ void PackedSurface::bltBlend(Surface &dest, int destX, int destY, ColorTable &co
             for (;;) {
                 if (rowData >= rowEnd) goto nextRow;
                 span = (SpanHead *)rowData;
-                x1 = span->x1;
-                x2 = x1 + span->len;
-                rowData += (sizeof(*span) + span->len*sizeof(PIX) + 3) & ~3;
+                x1 = ltoh16(span->x1);
+                x2 = x1 + ltoh16(span->len);
+                rowData += (sizeof(*span) + ltoh16(span->len)*sizeof(PIX) + 3) & ~3;
                 if (x2 > srcMin.x) break;
             }
 
@@ -526,36 +540,37 @@ void PackedSurface::bltBlend(Surface &dest, int destX, int destY, ColorTable &co
 
                 if (rowData >= rowEnd) goto nextRow;
                 span = (SpanHead *)rowData;
-                x1 = span->x1;
+                x1 = ltoh16(span->x1);
                 if (x1 >= srcMax.x) {
                     rowData = rowEnd;
                     goto nextRow;
                 }
-                x2 = x1 + span->len;
+                x2 = x1 + ltoh16(span->len);
                 data = (const PIX *)(span + 1);
-                rowData += (sizeof(*span) + span->len*sizeof(PIX) + 3) & ~3;
+                rowData += (sizeof(*span) + ltoh16(span->len)*sizeof(PIX) + 3) & ~3;
             }
 
 nextRow:
             assert(rowData == rowEnd);
-            destRowPtr += dest.getStride();
+            destRowPtr += dest.getPitch();
         }
     } else {
-        const uint8_t *rowData = packedDataChunk + table[srcMin.y];
-        PIX *destRowPtr = dest.rowPtr(destY + srcMin.y) + destX;
+        const Uint8 *rowData = packedDataChunk + table[srcMin.y];
+        PIX *destRowPtr = dest.pixPtr(0, destY + srcMin.y) + destX;
         for (int y = srcMin.y ; y < srcMax.y ; ++y) {
 
-            const uint8_t *rowEnd = packedDataChunk + table[y+1];
+            const Uint8 *rowEnd = packedDataChunk + table[y+1];
 
             while (rowData < rowEnd) {
                 SpanHead *span = (SpanHead *)rowData;
 
-                bltBlendSpan(destRowPtr + span->x1, (const PIX *)(span + 1), span->len, cTable);
+                bltBlendSpan(destRowPtr + ltoh16(span->x1),
+                    (const PIX *)(span + 1), ltoh16(span->len), cTable);
 
-                rowData += (sizeof(*span) + span->len*sizeof(PIX) + 3) & ~3;
+                rowData += (sizeof(*span) + ltoh16(span->len)*sizeof(PIX) + 3) & ~3;
             }
             assert(rowData == rowEnd);
-            destRowPtr += dest.getStride();
+            destRowPtr += dest.getPitch();
         }
     }
 
@@ -565,7 +580,7 @@ nextRow:
 //---------------------------------------------------------------------------
 int loadAllPAKInDirectory(const char *path, PackedSurfaceList& paklist)
 {
-    char** list = FileSystem::enumerateFiles(path);
+    char** list = filesystem::enumerateFiles(path);
 
     std::vector<std::string> filenames;
     for(char** file = list; *file != 0; file++) {
@@ -575,7 +590,7 @@ int loadAllPAKInDirectory(const char *path, PackedSurfaceList& paklist)
 	    filenames.push_back(name);
     }
 
-    FileSystem::freeList(list);
+    filesystem::freeList(list);
    
     std::sort(filenames.begin(), filenames.end()); 
 
