@@ -18,35 +18,39 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #ifndef __TCPLISTENSOCKET_HPP__
 #define __TCPLISTENSOCKET_HPP__
 
-#include <assert.h>
+#include "SocketBase.hpp"
 #include "TCPSocket.hpp"
+#include "NetworkException.hpp"
 
 namespace network
 {
+    
+class TCPListenSocket;    
+    
+class TCPListenSocketObserver {
+public:    
+    TCPListenSocketObserver() {};
+    virtual ~TCPListenSocketObserver() {};
+protected:
+    friend class TCPListenSocket;
+    virtual TCPSocketObserver * onNewConnection(TCPListenSocket *so, const Address &fromaddr) = 0;
+};
+    
 
-class TCPListenSocket : public TCPSocket
+class TCPListenSocket : public SocketBase
 {
 public:
-    /** creates a new listen socket and binds it to the specified address */
-    TCPListenSocket(const Address& bindaddr, bool blocking = true);
-
-    /** accepts a new client and returns it's socket or 0 when no client
-     * is connecting and we're in nonblocking mode 
-     */
-    TCPSocket* accept();
+    TCPListenSocket(const Address& bindaddr, TCPListenSocketObserver *o);
+    void destroy();
+    
+protected:
+    ~TCPListenSocket() {};
+    
+    void onDataReady();
 
 private:
-    void createBind(bool blocking);
+    TCPListenSocketObserver * observer;
     
-    // forbidden on listening socket
-    void send(const void* , size_t )
-    { assert(false); }
-    size_t recv(void* , size_t )
-    { assert(false); }
-
-#ifdef USE_WINSOCK
-    bool blocking;
-#endif
 };
 
 }
