@@ -22,7 +22,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 namespace UI
 {
-    typedef uint8_t Color;    
+    typedef Uint8 Color;    
 };
 
 #endif
