@@ -28,14 +28,13 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 // split server:port string, doesn't always set the port
 void UtilInterface::splitServerPort(const std::string& server,std::string& address,int *port)
 {
-    unsigned int colon=server.find(':',0);
-    if(colon==std::string::npos) {
+    std::string::size_type colon = server.find(':',0);
+    if(colon == std::string::npos) {
         address=server;
-    }
-    else {
-        address=server.substr(0,colon);
+    } else {
+        address=server.substr(0, colon);
         colon++;
-        std::string port_str(server.substr(colon,server.length()-colon));
+        std::string port_str(server.substr(colon, server.length() - colon));
         port[0]=atoi(port_str.c_str());
     }
 }
