@@ -19,7 +19,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #include <iostream>
 
-#include <SDL.h>
+#include "SDL.h"
 #include <stdlib.h>
 #include <assert.h>
 
