@@ -20,11 +20,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #include "NetPacketQueues.hpp"
 
-void EnqueueIncomingPacket( void *message, unsigned long message_size,
-                            SocketClient::ID toID, SocketClient::ID fromID );
-
-void EnqueueUnreliablePacket( void *message, unsigned long message_size,
-                              SocketClient::ID toID, SocketClient::ID fromID );
+void EnqueueIncomingPacket(const void *message, Uint16 message_size,
+                           NetClientID toID, NetClientID fromID);
 
 class NetworkInterface
 {
@@ -34,7 +31,7 @@ public:
     static NetPacketQueue receive_queue;
 
 public:
-    NetworkInterface( void );
+    NetworkInterface();
     ~NetworkInterface();
 };
 
