@@ -18,10 +18,10 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #ifndef _POWERUP_NET_MESSAGE_HPP
 #define _POWERUP_NET_MESSAGE_HPP
 
-#include "NetPacket.hpp"
+#include "NetMessage.hpp"
 
-#include "UnitID.hpp"
 #include "PlayerID.hpp"
+#include "UnitBase.hpp"
 
 enum { _net_message_id_powerup_create,
        _net_message_id_powerup_hit
@@ -33,49 +33,75 @@ enum { _net_message_id_powerup_create,
 
 class PowerUpCreateMesg : public NetMessage
 {
+private:
+    Sint32 map_loc_x;
+    Sint32 map_loc_y;
+    Sint32 ID;
+    Sint32 type;
+
 public:
-    int32_t map_loc_x;
-    int32_t map_loc_y;
-    int32_t ID;
-    int32_t type;
-
-    void set( iXY map_loc, int ID, int type )
-    {
-        PowerUpCreateMesg::map_loc_x = map_loc.x;
-        PowerUpCreateMesg::map_loc_y = map_loc.y;
-        PowerUpCreateMesg::ID = ID;
-        PowerUpCreateMesg::type = type;
-    }
-
     PowerUpCreateMesg()
     {
         message_class = _net_message_class_powerup;
         message_id = _net_message_id_powerup_create;
     }
+    void set(iXY map_loc, int ID, int type)
+    {
+        this->map_loc_x = htol32(map_loc.x);
+        this->map_loc_y = htol32(map_loc.y);
+        this->ID = htol32(ID);                      
+        this->type = htol32(type);
+    }
+    Sint32 getLocX() const
+    {
+        return ltoh32(map_loc_x);
+    }
+    Sint32 getLocY() const
+    {
+        return ltoh32(map_loc_y);
+    }
+    Sint32 getID() const
+    {
+        return ltoh32(ID);
+    }
+    Sint32 getType() const
+    {
+        return ltoh32(type);
+    }
 } __attribute__((packed));
 
 class PowerUpHitMesg : public NetMessage
 {
+private:
+    Sint32  ID;
+    Uint16 dummy; // XXX only here for compatibility reasons
+    Uint16 player_id;
+    Sint32  unit_powerup_type;
+
 public:
-    int32_t  ID;
-    UnitID   unit_id;
-    uint16_t player_id;
-    int32_t  unit_powerup_type;
-
-    void set( int ID, UnitID unit_id, PlayerID player_id )
-    {
-        PowerUpHitMesg::ID = ID;
-        PowerUpHitMesg::unit_id = unit_id;
-        PowerUpHitMesg::player_id = player_id.getIndex();
-        unit_powerup_type = 0;
-    }
-
     PowerUpHitMesg()
     {
         message_class = _net_message_class_powerup;
         message_id = _net_message_id_powerup_hit;
     }
-
+    void set(int ID, Uint16 player_id, int type=0)
+    {
+        this->ID = htol32(ID);
+        this->player_id = htol16(player_id);
+        this->unit_powerup_type = htol32(type);
+    }
+    Sint32 getID() const
+    {
+        return ltoh32(ID);
+    }
+    Uint16 getPlayerID() const
+    {
+        return ltoh16(player_id);
+    }
+    Sint32 getUnitPowerupType() const
+    {
+        return ltoh32(unit_powerup_type);
+    }
 } __attribute__((packed));
 
 #ifdef MSVC
