@@ -17,9 +17,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 #include <config.h>
 #include "ServerConnectDaemon.hpp"
-
+#include "ChatInterface.hpp"
 #include "NetworkGlobals.hpp"
-
 #include "PlayerInterface.hpp"
 #include "UnitInterface.hpp"
 #include "ObjectiveInterface.hpp"
@@ -29,6 +28,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "NetworkServer.hpp"
 #include "GameManager.hpp"
 #include "GameConfig.hpp"
+#include "SelectionBoxSprite.hpp"
 
 #include "PlayerNetMessage.hpp"
 #include "ConnectNetMessage.hpp"
@@ -37,33 +37,28 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "ConsoleInterface.hpp"
 #include "Util/Log.hpp"
 
-enum { _connect_state_idle,
-       _connect_state_wait_for_connect_request,
-       _connect_state_attempt_player_alloc,
-       _connect_state_wait_for_client_settings,
-       _connect_state_wait_for_client_game_setup_ack,
-       _connect_state_player_state_sync,
-       _connect_state_unit_sync
-     };
-
-
-unsigned char       ServerConnectDaemon::connection_state = _connect_state_idle;
+ServerConnectDaemon::ConnectionState
+                    ServerConnectDaemon::connection_state 
+						= ServerConnectDaemon::connect_state_idle;
 bool                ServerConnectDaemon::connection_lock_state = false;
 PlayerID            ServerConnectDaemon::connect_player_id;
 PlayerState*        ServerConnectDaemon::connect_player_state;
 std::list<ConnectQueueElement> ServerConnectDaemon::connect_queue;
 Timer		    ServerConnectDaemon::time_out_timer;
 int	            ServerConnectDaemon::time_out_counter;
+Timer               ServerConnectDaemon::sendunitpercent_timer;
 UnitSync*           ServerConnectDaemon::connect_unit_sync = 0;
 
 #define _SERVER_CONNECT_TIME_OUT_TIME (20.0)
 #define _SERVER_CONNECT_RETRY_LIMIT   (5)
+#define _SENDUNITPERCENT_TIME (1)
 
 
 void ServerConnectDaemon::initialize(unsigned long max_players)
 {
     (void) max_players;
     time_out_timer.changePeriod( _SERVER_CONNECT_TIME_OUT_TIME );
+    sendunitpercent_timer.changePeriod( _SENDUNITPERCENT_TIME );
     connect_unit_sync = 0;
 }
 
@@ -71,6 +66,7 @@ void ServerConnectDaemon::startConnectDaemon( unsigned long max_players )
 {
     (void) max_players;
     time_out_timer.changePeriod( _SERVER_CONNECT_TIME_OUT_TIME );
+    sendunitpercent_timer.changePeriod( _SENDUNITPERCENT_TIME );
 }
 
 void ServerConnectDaemon::shutdownConnectDaemon()
@@ -95,7 +91,7 @@ bool ServerConnectDaemon::inConnectQueue( PlayerID &new_player_id )
         }
     }
 
-    if ( (connection_state != _connect_state_idle) &&
+    if ( (connection_state != connect_state_idle) &&
             (connect_player_id.getNetworkID() == new_player_id.getNetworkID()  )
        )
         return true;
@@ -122,19 +118,15 @@ void ServerConnectDaemon::updateQueuedClients()
 
 }
 
-void ServerConnectDaemon::netMessageClientDisconnect(const NetMessage *message)
+void ServerConnectDaemon::netPacketClientDisconnect(const NetPacket *packet)
 {
-    ConnectMesgNetPanzerClientDisconnect *client_disconnect;
-
-    client_disconnect = (ConnectMesgNetPanzerClientDisconnect *) message;
-
-    if(client_disconnect->getPlayerID() >= PlayerInterface::getMaxPlayers()) {
-        LOGGER.warning("Received malformed disconnection message.");
-        return;
-    }
-    
-    startDisconnectionProcess(
-            PlayerInterface::getPlayerID(client_disconnect->getPlayerID()) );
+    // Note: this invalidates the ConnectMesgNetPanzerClientDisconnect playerID
+    // value, just use the networkID, this way avoid possible fake packet
+    // to kick other player.
+    // In a future protocol version PlayerID should be removed from this packet.
+    PlayerState *player = PlayerInterface::getPlayerByNetworkID(packet->fromID);
+    if (player)
+        startDisconnectionProcess(player->getPlayerID());
 }
 
 void ServerConnectDaemon::netPacketClientJoinRequest(const NetPacket* packet)
@@ -179,7 +171,7 @@ void ServerConnectDaemon::processNetPacket(const NetPacket* packet)
 
     switch(message->message_id) {
         case _net_message_id_connect_netPanzer_client_disconnect:
-            netMessageClientDisconnect(message);
+            netPacketClientDisconnect(packet);
             break;
 
         case _net_message_id_connect_join_game_request:
@@ -205,6 +197,15 @@ void ServerConnectDaemon::sendConnectionAlert(PlayerID &player_id, int alert_enu
             connect_alert.set( player_id, _connect_alert_mesg_connect );
             ConsoleInterface::postMessage( "'%s' has joined the game.",
                     player_state->getName().c_str() );
+           const char* motd=gameconfig->motd.c_str();
+           if (*motd!='\0'){
+               ChatMesg chat_mesg;
+               chat_mesg.message_scope=_chat_mesg_scope_server;
+               chat_mesg.setSourcePlayerIndex(0);
+               snprintf(chat_mesg.message_text, sizeof(chat_mesg.message_text), "%s",gameconfig->motd.c_str());
+               SERVER->sendMessage(player_state->getNetworkID(),&chat_mesg, sizeof(chat_mesg));
+           }
+
         }
         break;
 
@@ -217,10 +218,7 @@ void ServerConnectDaemon::sendConnectionAlert(PlayerID &player_id, int alert_enu
 
     case _connect_alert_mesg_client_drop : {
             connect_alert.set( player_id, _connect_alert_mesg_client_drop );
-            ConsoleInterface::postMessage(
-                    "Connection to '%s' has been unexpectedly broken.",
-                    player_state->getName().c_str() );
-            ConsoleInterface::postMessage( "'%s' has left the game.",
+            ConsoleInterface::postMessage( "'%s' has left the game for some reason.",
                     player_state->getName().c_str() );
         }
         break;
@@ -234,7 +232,7 @@ void ServerConnectDaemon::sendConnectionAlert(PlayerID &player_id, int alert_enu
 
 void ServerConnectDaemon::resetConnectFsm()
 {
-    connection_state = _connect_state_idle;
+    connection_state = connect_state_idle;
     time_out_timer.reset();
     time_out_counter = 0;
 }
@@ -248,7 +246,7 @@ bool ServerConnectDaemon::connectStateIdle()
         connect_request   = connect_queue.front();
         connect_queue.pop_front();
         connect_player_id = connect_request.new_player_id;
-        connection_state  = _connect_state_wait_for_connect_request;
+        connection_state  = connect_state_wait_for_connect_request;
 
         ClientConnectStartConnect start_connect;
 
@@ -269,68 +267,42 @@ bool ServerConnectDaemon::connectStateIdle()
 bool ServerConnectDaemon::connectStateWaitForConnectRequest(
         const NetMessage* message)
 {
-    if (message != 0) {
-        if ( message->message_id == _net_message_id_client_connect_request ) {
-            connection_state = _connect_state_attempt_player_alloc;
-            return false;
-        } else {
-            if ( time_out_timer.count() ) {
-                resetConnectFsm();
-                return true;
-            }
+    if (message && message->message_id == _net_message_id_client_connect_request ) {
 
-            return true;
-        }
+        ClientConnectResult connect_result;
+        connect_player_state = PlayerInterface::allocateNewPlayer();
 
-    } // ** if ( message != 0 )
-    else {
-        if ( time_out_timer.count() ) {
+        if ( connect_player_state == 0 ) {
+            connect_result.result_code = _connect_result_server_full;
             resetConnectFsm();
-            return true;
+        } else {
+            connect_result.result_code = _connect_result_success;
+            time_out_timer.reset();
         }
 
-        return true;
-    }
+        SERVER->sendMessage( connect_player_id, &connect_result,
+                                                sizeof(ClientConnectResult));
+
+        if ( connection_state != connect_state_idle )
+            connection_state = connect_state_wait_for_client_settings;
+
+    } else if ( time_out_timer.count() )
+        resetConnectFsm();
 
     return true;
 }
 
-bool ServerConnectDaemon::connectStateAttemptPlayerAlloc()
-{
-    ClientConnectResult connect_result;
-    connect_player_state = PlayerInterface::allocateNewPlayer();
-
-    if ( connect_player_state == 0 ) {
-        connect_result.result_code = _connect_result_server_full;
-
-        SERVER->sendMessage( connect_player_id, &connect_result,
-                                            sizeof(ClientConnectResult));
-        resetConnectFsm();
-        return true;
-    } else {
-        connect_result.result_code = _connect_result_success;
-
-        SERVER->sendMessage( connect_player_id, &connect_result,
-                                            sizeof(ClientConnectResult));
-
-        time_out_timer.reset();
-        connection_state = _connect_state_wait_for_client_settings;
-        return true;
-    }
-
-}
-
 bool ServerConnectDaemon::connectStateWaitForClientSettings(
         const NetMessage* message )
 {
-    if ( message != 0 ) {
-        if ( message->message_id == _net_message_id_connect_client_settings ) {
+    if ( message && message->message_id == _net_message_id_connect_client_settings ) {
             ConnectClientSettings *client_setting;
 
             client_setting = (ConnectClientSettings *) message;
             connect_player_state->setName( client_setting->player_name );
             connect_player_state->unit_config.setUnitColor( client_setting->unit_color );
-            connect_player_state->setFlag( client_setting->getPlayerFlag() );
+			Uint8 flag = (Uint8) client_setting->getPlayerFlag();
+            connect_player_state->setFlag(flag);
 
             connect_player_state->setID( connect_player_id.getNetworkID() );
             connect_player_state->setStatus( _player_state_connecting );
@@ -344,25 +316,15 @@ bool ServerConnectDaemon::connectStateWaitForClientSettings(
             delete server_game_setup;
 
             time_out_timer.reset();
-            connection_state = _connect_state_wait_for_client_game_setup_ack;
+			if(connection_state != connect_state_idle) {
+				connection_state = connect_state_wait_for_client_game_setup_ack;
+			}
             return true;
-        } else {
-            if ( time_out_timer.count() ) {
-                connect_player_state->setStatus( _player_state_free );
-                resetConnectFsm();
-                return true;
-            }
+    }
 
-            return true;
-        }
-    } else {
-        if ( time_out_timer.count() ) {
-            connect_player_state->setStatus( _player_state_free );
-            resetConnectFsm();
-            return true;
-        }
-
-        return true;
+    if ( time_out_timer.count() ) {
+        connect_player_state->setStatus( _player_state_free );
+        resetConnectFsm();
     }
 
     return true;
@@ -382,31 +344,22 @@ bool ServerConnectDaemon::connectStateWaitForClientGameSetupAck(
 
             ConnectProcessStateMessage state_mesg;
             state_mesg.setMessageEnum(_connect_state_message_sync_player_info);
+            state_mesg.setPercentComplete(0);
             SERVER->sendMessage(connect_player_id, &state_mesg,
                     sizeof(ConnectProcessStateMessage));
-            connection_state = _connect_state_player_state_sync;
-        } else
-            if ( message->message_id == _net_message_id_connect_client_game_setup_ping ) {
-                time_out_timer.reset();
-                return true;
-            } else {
-                if ( time_out_timer.count() ) {
-                    connect_player_state->setStatus( _player_state_free );
-                    resetConnectFsm();
-                    return true;
-                }
-
-                return true;
-            }
-
-    } else {
-        if ( time_out_timer.count() ) {
-            connect_player_state->setStatus( _player_state_free );
-            resetConnectFsm();
+			if(connection_state != connect_state_idle) {
+				connection_state = connect_state_player_state_sync;
+			}
+			return true;
+        } else if ( message->message_id == _net_message_id_connect_client_game_setup_ping ) {
+            time_out_timer.reset();
             return true;
         }
+    }
 
-        return true;
+    if ( time_out_timer.count() ) {
+        connect_player_state->setStatus( _player_state_free );
+        resetConnectFsm();
     }
 
     return true;
@@ -424,6 +377,7 @@ bool ServerConnectDaemon::connectStatePlayerStateSync()
                 sizeof(ConnectProcessStateMessage));
         delete connect_unit_sync;
         connect_unit_sync = new UnitSync();
+        sendunitpercent_timer.reset();
 
         state_mesg.setMessageEnum(_connect_state_message_sync_units);
         SERVER->sendMessage( connect_player_id, &state_mesg,
@@ -434,7 +388,9 @@ bool ServerConnectDaemon::connectStatePlayerStateSync()
             (connect_player_state->getNetworkPlayerState());
 
         SERVER->sendMessage(&player_state_update, sizeof(PlayerStateSync));
-        connection_state = _connect_state_unit_sync;
+		if(connection_state != connect_state_idle) {
+			connection_state = connect_state_unit_sync;
+		}
         return true;
     } else if ( percent_complete > 0 ) {
         state_mesg.setMessageEnum(_connect_state_message_sync_player_info_percent);
@@ -453,16 +409,19 @@ bool ServerConnectDaemon::connectStateUnitSync()
 
     // send a unit
     if(connect_unit_sync->sendNextUnit(connect_player_id)) {
-        state_mesg.setMessageEnum(_connect_state_message_sync_units_percent);
-        state_mesg.setPercentComplete(percent_complete);
-        SERVER->sendMessage(connect_player_id, &state_mesg,
-                sizeof(ConnectProcessStateMessage));
+        if ( sendunitpercent_timer.count() ) {
+            state_mesg.setMessageEnum(_connect_state_message_sync_units_percent);
+            state_mesg.setPercentComplete(percent_complete);
+            SERVER->sendMessage(connect_player_id, &state_mesg,
+                    sizeof(ConnectProcessStateMessage));
+            sendunitpercent_timer.reset();
+        }
         return true;
     }
 
     // Sending finished
     state_mesg.setMessageEnum(_connect_state_message_sync_units_percent);
-    state_mesg.setPercentComplete(percent_complete);
+    state_mesg.setPercentComplete(100);
     SERVER->sendMessage( connect_player_id, &state_mesg,
             sizeof(ConnectProcessStateMessage));
 
@@ -488,7 +447,7 @@ bool ServerConnectDaemon::connectStateUnitSync()
             sizeof(ConnectProcessStateMessage));
     sendConnectionAlert( connect_player_id, _connect_alert_mesg_connect );
 
-    connection_state = _connect_state_idle;
+    connection_state = connect_state_idle;
     return true;
 }
 
@@ -498,77 +457,35 @@ void ServerConnectDaemon::connectFsm(const NetMessage* message)
 
     do {
         switch ( connection_state ) {
-        case _connect_state_idle : {
-                if ( connectStateIdle() ) {
-                    end_cycle = true;
-                } else {
-                    end_cycle = false;
-                }
+            case connect_state_idle:
+                end_cycle = connectStateIdle();
+                break;
 
-            }
-            break;
+            case connect_state_wait_for_connect_request:
+                end_cycle = connectStateWaitForConnectRequest( message );
+                break;
 
-        case _connect_state_wait_for_connect_request : {
-                if ( connectStateWaitForConnectRequest( message ) ) {
-                    end_cycle = true;
-                } else {
-                    end_cycle = false;
-                }
-            }
-            break;
+            case  connect_state_wait_for_client_settings:
+                end_cycle = connectStateWaitForClientSettings( message );
+                break;
 
+            case connect_state_wait_for_client_game_setup_ack:
+                end_cycle = connectStateWaitForClientGameSetupAck( message );
+                break;
 
-        case _connect_state_attempt_player_alloc : {
-                if ( connectStateAttemptPlayerAlloc( ) ) {
-                    end_cycle = true;
-                } else {
-                    end_cycle = false;
-                }
-            }
-            break;
+            case connect_state_player_state_sync:
+                end_cycle = connectStatePlayerStateSync();
+                break;
 
+            case connect_state_unit_sync:
+                end_cycle = connectStateUnitSync();
+                break;
 
-        case  _connect_state_wait_for_client_settings : {
-                if ( connectStateWaitForClientSettings( message ) ) {
-                    end_cycle = true;
-                } else {
-                    end_cycle = false;
-                }
-            }
-            break;
-
-        case _connect_state_wait_for_client_game_setup_ack : {
-                if ( connectStateWaitForClientGameSetupAck( message ) ) {
-                    end_cycle = true;
-                } else {
-                    end_cycle = false;
-                }
-            }
-            break;
-
-        case _connect_state_player_state_sync : {
-                if ( connectStatePlayerStateSync( ) ) {
-                    end_cycle = true;
-                } else {
-                    end_cycle = false;
-                }
-            }
-            break;
-
-        case _connect_state_unit_sync : {
-                if ( connectStateUnitSync( ) ) {
-                    end_cycle = true;
-                } else {
-                    end_cycle = false;
-                }
-            }
-            break;
+            default:
+                assert("Bad connection state" == 0);
 
         } // ** switch
-
     } while( end_cycle == false );
-
-
 }
 
 void ServerConnectDaemon::connectProcess(const NetMessage* message)
@@ -586,10 +503,23 @@ bool ServerConnectDaemon::disconnectClient( PlayerID player_id )
     SERVER->shutdownClientTransport(player_id.getNetworkID());
 
     SERVER->removeClientFromSendList(player_id);
-    ObjectiveInterface::disownPlayerObjectives( player_id );
+    ObjectiveInterface::disownPlayerObjectives(player_id.getIndex());
     UnitInterface::destroyPlayerUnits(player_id.getIndex());
     PlayerInterface::disconnectPlayerCleanup( player_id );
 
+	for(std::list<ConnectQueueElement>::iterator i = connect_queue.begin();
+			i != connect_queue.end(); /*nothing */) {
+		if(i->new_player_id == player_id) {
+			i = connect_queue.erase(i);
+			continue;
+		}
+
+		++i;
+	}
+	if(connect_player_id == player_id) {
+		connection_state = connect_state_idle;
+	}
+
     return true;
 }
 
@@ -625,7 +555,7 @@ bool ServerConnectDaemon::getConnectLockStatus()
 
 bool ServerConnectDaemon::isConnecting()
 {
-    if( connection_state == _connect_state_idle ) {
+    if( connection_state == connect_state_idle ) {
         return false;
     }
 
