@@ -45,15 +45,13 @@ void ServerMessageRouter::cleanUp()
 {
 }
 
-void ServerMessageRouter::classTerminalMessages(const NetMessage* message)
+void ServerMessageRouter::processTerminalPacket(const NetPacket* packet)
 {
+    const NetMessage* message = packet->getNetMessage();
     switch(message->message_id) {
-        case _net_message_id_term_unit_cmd: {
-            const TerminalUnitCmdRequest *terminal_command
-                = (const TerminalUnitCmdRequest*) message;
-            UnitInterface::sendMessage( &(terminal_command->comm_request) );
+        case _net_message_id_term_unit_cmd:
+            UnitInterface::processNetPacket(packet);
             break;
-        }
 
         case _net_message_id_term_unit_gen: {
             const TerminalOutpostUnitGenRequest* terminal_command
@@ -69,8 +67,8 @@ void ServerMessageRouter::classTerminalMessages(const NetMessage* message)
             break;
         }
         default:
-            LOGGER.warning("unnown Terminal Message (id %d)",
-                    message->message_id);
+            LOGGER.warning("unnown Terminal Message (id %d, player %u)",
+                    message->message_id, packet->fromID);
     }
 }
 
@@ -79,7 +77,7 @@ void ServerMessageRouter::routePacket(const NetPacket* packet)
     const NetMessage* message = packet->getNetMessage();
     switch (message->message_class) {
         case _net_message_class_terminal:
-            classTerminalMessages(message);
+            processTerminalPacket(packet);
             break;
 
         case _net_message_class_system:
