@@ -39,7 +39,7 @@ enum { _net_message_id_opcode_mesg,
 class UnitOpcodeMessage : public NetMessage
 {
 public:
-    uint8_t data[ _OPCODE_MESSAGE_LIMIT ];
+    Uint8 data[ _OPCODE_MESSAGE_LIMIT ];
     
     UnitOpcodeMessage()
     {
@@ -58,28 +58,49 @@ public:
 class UnitIniSyncMessage : public NetMessage
 {
 public:
-    uint8_t unit_type;
+    Uint8 unit_type;
 private:
-    uint8_t player_id;
-    uint16_t unit_id;
-    uint32_t location_x;
-    uint32_t location_y;
+    // XXX this should really be Uint16 player_id;
+    Uint8 player_id;
+    Uint16 unit_id;
+    Uint32 location_x;
+    Uint32 location_y;
 public:
     NetworkUnitState unit_state;
 
-    UnitIniSyncMessage(uint8_t unit_type, uint16_t player_id, UnitID unit_id,
-        uint32_t location_x, uint32_t location_y);
-    unsigned short realSize() const;
-    uint32_t getLocX() const;
-    uint32_t getLocY() const;
+    UnitIniSyncMessage(Uint8 unit_type, Uint16 player_id, UnitID unit_id,
+        Uint32 location_x, Uint32 location_y)
+    {
+        message_class = _net_message_class_unit;
+        message_id = _net_message_id_ini_sync_mesg;
+        this->unit_type = unit_type;
+        //this->player_id = htol16(player_id);
+        this->player_id = (Uint8) player_id;
+        this->unit_id = htol16(unit_id);
+        this->location_x = htol32(location_x);
+        this->location_y = htol32(location_y);
+    }
+      
+    unsigned short realSize() const
+    {
+        return( sizeof( UnitIniSyncMessage ) );
+    }
+    Uint32 getLocX() const
+    {
+        return ltoh32(location_x);
+    }
+    Uint32 getLocY() const
+    {
+        return ltoh32(location_y);
+    }
 
     UnitID getUnitID() const
     {
         return ltoh16(unit_id);
     }
-    uint16_t getPlayerID() const
+    Uint16 getPlayerID() const
     {
-        return ltoh16(player_id);
+        return player_id;
     }
 } __attribute__((packed));
 
@@ -88,7 +109,7 @@ public:
 class UnitRemoteDestroy : public NetMessage
 {
 private:
-    uint16_t unit_to_destroy;
+    Uint16 unit_to_destroy;
 
 public:
     UnitRemoteDestroy()
@@ -111,22 +132,38 @@ public:
 class UnitRemoteCreate : public NetMessage
 {
 private:
-    uint16_t player_id;
-    uint16_t new_unit_id;
-    uint32_t location_x;
-    uint32_t location_y;
+    Uint16 player_id;
+    Uint16 new_unit_id;
+    Uint32 location_x;
+    Uint32 location_y;
 public:
-    uint8_t unit_type;
+    Uint8 unit_type;
 
-    UnitRemoteCreate(uint16_t player_id, UnitID id,
-            uint32_t x, uint32_t y, uint8_t type);
-    uint32_t getLocX() const;
-    uint32_t getLocY() const;
+    UnitRemoteCreate(Uint16 player_id, UnitID id,
+            Uint32 x, Uint32 y, Uint8 type)
+    {
+        message_class = _net_message_class_unit;
+        message_id = _net_message_id_create_unit;
+        this->player_id = htol16(player_id);             
+        new_unit_id = htol16(id);
+        location_x = htol32(x);
+        location_y = htol32(y);
+        unit_type = type;
+    }
+        
+    Uint32 getLocX() const
+    {
+        return ltoh32(location_x);
+    }
+    Uint32 getLocY() const
+    {
+        return ltoh32(location_y);
+    }
     UnitID getUnitID() const
     {
         return ltoh16(new_unit_id);
     }
-    uint16_t getPlayerID() const
+    Uint16 getPlayerID() const
     {
         return ltoh16(player_id);
     }
