@@ -18,8 +18,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #ifndef _PLAYERID_HPP
 #define _PLAYERID_HPP
 
-#include <stdint.h>
-#include "Network/SocketClient.hpp"
+#include "NetPacket.hpp"
 
 class PlayerID
 {
@@ -28,7 +27,7 @@ public:
             : index_id(0xFFFF), networkid(0xFFFFFFFF)
     { }
 
-    PlayerID(uint16_t index, SocketClient::ID newid)
+    PlayerID(Uint16 index, NetClientID newid)
             : index_id(index), networkid(newid)
     { }
 
@@ -42,22 +41,22 @@ public:
         networkid = other.networkid;
     }
 
-    void setIndex(uint16_t index)
+    void setIndex(Uint16 index)
     {
         index_id = index;
     }
 
-    uint16_t getIndex() const
+    Uint16 getIndex() const
     {
         return index_id;
     }
 
-    void setNetworkID(SocketClient::ID newid)
+    void setNetworkID(NetClientID newid)
     {
         networkid = newid;
     }
 
-    SocketClient::ID getNetworkID() const
+    NetClientID getNetworkID() const
     {
         return networkid;
     }
@@ -71,8 +70,8 @@ public:
     }
 
 private:
-    uint16_t index_id;
-    SocketClient::ID networkid;
+    Uint16 index_id;
+    NetClientID networkid;
 };
 
 #endif // ** _PLAYERID_HPP
