@@ -18,7 +18,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #ifndef _UNITOPCODES_HPP
 #define _UNITOPCODES_HPP
 
-#include <stdint.h>
+#include "UnitBase.hpp"
 #include <queue>
 
 enum { _unit_opcode_flag_sync = 0x01 };
@@ -36,37 +36,60 @@ enum { _unit_opcode_flag_sync = 0x01 };
 #pragma pack(1)
 #endif
 
+// do not use this directly, cast to 1 of the UnitOpcode classes...
 struct UnitOpcodeStruct
 {
-    uint8_t opcode;
-    uint8_t player_index;
-    uint16_t unit_index;
-    uint8_t flags;
-
-    uint8_t op_data[7];
+public:
+    Uint8 opcode;
+private:
+    Uint16 unit_index;
+public:
+    Uint8 flags;
+private:
+    Uint8 op_data[7];
 } __attribute__((packed));
 
-
-typedef std::queue< UnitOpcodeStruct > UnitOpcodeQueue;
+typedef std::queue<UnitOpcodeStruct> UnitOpcodeQueue;
 
 class UnitOpcode
 {
 public:
-    uint8_t opcode;
-    uint8_t player_index;
-    uint16_t unit_index;
-    uint8_t flags;
+    Uint8 opcode;
+    //Uint8 player_index;
+private:
+    Uint16 unit_id;
+public:
+    Uint8 flags;
+
+    static size_t getSize()
+    {
+        return sizeof(UnitOpcodeStruct);
+    }
+
+    void setUnitID(UnitID id)
+    {
+        unit_id = htol16(id);
+    }
+
+    UnitID getUnitID() const
+    {
+        return ltoh16(unit_id);
+    }
 } __attribute__((packed));
 
+ASSERT_SIZE(UnitOpcode, sizeof(UnitOpcodeStruct)-7)
+
 #define _UNIT_OPCODE_MOVE 1
 
 class MoveOpcode : public UnitOpcode
 {
+private:
+    Uint32 square;
+
 public:
-    uint32_t square;
-    int8_t loc_x_offset;
-    int8_t loc_y_offset;
-    uint8_t pad[1];
+    Sint8 loc_x_offset;
+    Sint8 loc_y_offset;
+    Uint8 pad[1];
 
     MoveOpcode( )
     {
@@ -78,6 +101,16 @@ public:
         loc_y_offset = 0;
         pad[0] = 0;
     }
+
+    void setSquare(Uint32 square)
+    {
+        this->square = htol32(square);
+    }
+
+    Uint32 getSquare() const
+    {
+        return ltoh32(square);
+    }
 } __attribute__((packed));
 
 ASSERT_SIZE(MoveOpcode, 7 + sizeof(UnitOpcode))
@@ -86,22 +119,34 @@ ASSERT_SIZE(MoveOpcode, 7 + sizeof(UnitOpcode))
 
 class TurretTrackPointOpcode : public UnitOpcode
 {
+private:
+    Uint16 target_x;
+    Uint16 target_y;
+
 public:
-    uint16_t x;
-    uint16_t y;
-    uint8_t  activate;
-    uint8_t pad[2];
+    Uint8  activate;
+    Uint8 pad[2];
 
     TurretTrackPointOpcode( )
     {
         flags = 0;
         opcode = _UNIT_OPCODE_TURRET_TRACK_POINT;
 
-        x = y = 0;
+        target_x = target_y = 0;
         activate = false;
         pad[0] = pad[1] = 0;
     }
 
+    void setTarget(iXY pos)
+    {
+        target_x = htol16(pos.x);
+        target_y = htol16(pos.y);
+    }
+
+    iXY getTarget() const
+    {
+        return iXY(ltoh16(target_x), ltoh16(target_y));
+    }
 } __attribute__((packed));
 
 ASSERT_SIZE(TurretTrackPointOpcode, 7 + sizeof(UnitOpcode))
@@ -110,21 +155,30 @@ ASSERT_SIZE(TurretTrackPointOpcode, 7 + sizeof(UnitOpcode))
 
 class TurretTrackTargetOpcode : public UnitOpcode
 {
+private:
+    Uint16 targetUnitID;
 public:
-    uint8_t target_player_index;
-    uint16_t target_unit_index;
-    uint8_t activate;
-    uint8_t pad[3];
+    Uint8 activate;
+    Uint8 pad[4];
 
     TurretTrackTargetOpcode( )
     {
         flags = 0;
         opcode = _UNIT_OPCODE_TURRET_TRACK_TARGET;
 
-        target_player_index = 0;
-        target_unit_index = 0;
+        targetUnitID = 0;
         activate = false;
-        pad[0] = pad[1] = pad[2] = 0;
+        pad[0] = pad[1] = pad[2] = pad[3] = 0;
+    }
+
+    void setTargetUnitID(UnitID id)
+    {
+        targetUnitID = htol16(id);
+    }
+    
+    UnitID getTargetUnitID() const
+    {
+        return ltoh16(targetUnitID);
     }
 } __attribute__((packed));
 
@@ -134,10 +188,12 @@ ASSERT_SIZE(TurretTrackTargetOpcode, 7 + sizeof(UnitOpcode))
 
 class FireWeaponOpcode : public UnitOpcode
 {
+private:
+    Uint16 x;
+    Uint16 y;
+    Uint8 pad[3];
+    
 public:
-    uint16_t x;
-    uint16_t y;
-    uint8_t pad[3];
 
     FireWeaponOpcode( )
     {
@@ -147,6 +203,17 @@ public:
         x = y = 0;
         pad[0] = pad[1] = pad[2] = 0;
     }
+
+    void setTarget(iXY target)
+    {
+        x = htol16(target.x);
+        y = htol16(target.y);
+    }
+
+    iXY getTarget() const
+    {
+        return iXY(ltoh16(x), ltoh16(y));
+    }
 } __attribute__((packed));
 
 ASSERT_SIZE(FireWeaponOpcode, 7 + sizeof(UnitOpcode))
@@ -156,7 +223,7 @@ ASSERT_SIZE(FireWeaponOpcode, 7 + sizeof(UnitOpcode))
 class SyncUnitOpcode : public UnitOpcode
 {
 public:
-    uint8_t pad[7];
+    Uint8 pad[7];
 
     SyncUnitOpcode( )
     {
@@ -175,9 +242,10 @@ ASSERT_SIZE(SyncUnitOpcode, 7 + sizeof(UnitOpcode))
 
 class UpdateStateUnitOpcode : public UnitOpcode
 {
+private:
+    Sint16 hit_points;
 public:
-    int16_t hit_points;
-    uint8_t pad[5];
+    Uint8 pad[5];
 
     UpdateStateUnitOpcode( )
     {
@@ -187,6 +255,16 @@ public:
         for(int i=0; i<5; i++)
             pad[i] = 0;
     }
+
+    void setHitPoints(Sint16 newhitpoints)
+    {
+        hit_points = htol16(newhitpoints);
+    }
+
+    Sint16 getHitPoints() const
+    {
+        return ltoh16(hit_points);
+    }
 } __attribute__((packed));
 
 ASSERT_SIZE(UpdateStateUnitOpcode, 7 + sizeof(UnitOpcode))
