@@ -17,6 +17,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 #include <config.h>
 
+#include <stdexcept>
+
 #include <string.h>
 #include "Util/Log.hpp"
 #include "Vehicle.hpp"
@@ -42,8 +44,10 @@ Vehicle::Vehicle(PlayerState* player, UnitID id, iXY initial_loc)
     smolderWait    = 0.0f;
     smolderWaitMin = 0.0f;
 
-    iXY loc;
-    MapInterface::mapXYtoPointXY( initial_loc, &loc );
+    if(!MapInterface::inside(initial_loc))
+        throw std::runtime_error("Invalid position");
+
+    iXY loc = MapInterface::mapXYtoPointXY(initial_loc);
     unit_state.location = loc;
     UnitBlackBoard::markUnitLoc( initial_loc );
     fsm_timer.changeRate( 10 );
@@ -342,7 +346,7 @@ bool Vehicle::fsmMove()
 
 void Vehicle::setFsmMoveMapSquare( unsigned long square )
 {
-    long goal_angle;
+    long goal_angle = 0;
     long delta;
     unsigned short rotation;
 
@@ -1293,7 +1297,7 @@ void Vehicle::aiFsmDefendHold()
 void Vehicle::aiFsmManualMove()
 {
     bool end_cycle = false;
-    signed char offset_x, offset_y;
+    signed char offset_x = 0, offset_y = 0;
     size_t next_square;
 
     do {
@@ -1558,21 +1562,18 @@ void Vehicle::setCommandManualFire(const UMesgAICommand* message)
     setFsmGunneryLocation(message->getTargetLoc());
 }
 
-void Vehicle::messageAICommand(const UnitMessage* message )
+void Vehicle::messageAICommand(const UnitMessage* message)
 {
-    UMesgAICommand *command_mesg;
-
-    command_mesg = (UMesgAICommand *) message;
+    const UMesgAICommand *command_mesg = (const UMesgAICommand *) message;
 
     if ( unit_state.lifecycle_state == _UNIT_LIFECYCLE_ACTIVE ) {
-        if ( command_mesg->command == _command_manual_fire ) {
+        if (command_mesg->command == _command_manual_fire) {
             setCommandManualFire( command_mesg );
         } else {
             memcpy(&pending_AI_comm_mesg, command_mesg, sizeof(UMesgAICommand));
             pending_AI_comm = true;
         }
     }
-
 }
 
 
@@ -1612,28 +1613,26 @@ void Vehicle::messageWeaponHit(const UnitMessage *message)
 
 void Vehicle::messageSelectBoxUpdate(const UnitMessage* message)
 {
-    UMesgUpdateSelectBoxInfo *select_box_update;
+    const UMesgUpdateSelectBoxInfo *select_box_update 
+        = (const UMesgUpdateSelectBoxInfo *) message;
 
-    select_box_update = (UMesgUpdateSelectBoxInfo *) message;
-
-    switch ( select_box_update->request_type ) {
-    case _select_box_allie_visibility : {
-            select_info_box.setAllieIcon( select_box_update->allie_flag_visiblity );
+    switch (select_box_update->request_type) {
+        case _select_box_allie_visibility: {
+            select_info_box.setAllieIcon(select_box_update->allie_flag_visiblity );
+            break;
         }
         break;
 
-    case _select_box_flag_visiblity : {
+        case _select_box_flag_visiblity: {
             select_info_box.setFlagIcon( select_box_update->flag_visiblity );
+            break;
         }
-        break;
 
-    case _select_box_is_allied : {
+        case _select_box_is_allied: {
             select_info_box.setAllieState( select_box_update->allied_state );
+            break;
         }
-        break;
-
-    } // ** switch
-
+    }
 }
 
 void Vehicle::messageSelfDestruct(const UnitMessage* )
@@ -1647,7 +1646,6 @@ void Vehicle::messageSelfDestruct(const UnitMessage* )
     UnitBlackBoard::unmarkUnitLoc( current_map_loc );
 }
 
-
 void Vehicle::processMessage(const UnitMessage* message)
 {
     if (unit_state.lifecycle_state != _UNIT_LIFECYCLE_ACTIVE)
@@ -1673,6 +1671,7 @@ void Vehicle::processMessage(const UnitMessage* message)
         default:
             LOGGER.warning("Unknown unit message (id %d)",
                     message->message_id);
+            break;
     }
 }
 
