@@ -64,7 +64,7 @@ enum { _cursor_regular,
 
 enum { _keyboard_input_mode_command,
        _keyboard_input_mode_chat_mesg,
-       _keyboard_input_mode_allie_mesg,
+       _keyboard_input_mode_allie_mesg
      };
 
 short WorldInputCmdProcessor::selected_objective_id = 0;
@@ -109,12 +109,10 @@ WorldInputCmdProcessor::cycleSelectedUnits(unsigned long new_list_index)
 void
 WorldInputCmdProcessor::updateScrollStatus(const iXY &mouse_pos)
 {
-    iXY screen_size;
     double time_slice;
     long  scroll_increment;
     float scroll_rate;
 
-    screen_size = screen->getPix();
     time_slice = TimerInterface::getTimeSlice();
     scroll_rate = gameconfig->scrollrate;
 
@@ -149,7 +147,7 @@ WorldInputCmdProcessor::updateScrollStatus(const iXY &mouse_pos)
         return;
     }
 
-    if(mouse_pos.x >= (screen_size.x - 1)) {
+    if((unsigned int)mouse_pos.x >= (screen->getWidth() - 1)) {
         WorldViewInterface::scroll_right(scroll_increment);
     }
 
@@ -157,7 +155,7 @@ WorldInputCmdProcessor::updateScrollStatus(const iXY &mouse_pos)
         WorldViewInterface::scroll_left(scroll_increment);
     }
 
-    if( mouse_pos.y >= (screen_size.y - 1)) {
+    if( (unsigned int)mouse_pos.y >= (screen->getHeight() - 1)) {
         WorldViewInterface::scroll_down(scroll_increment);
     }
 
@@ -542,11 +540,9 @@ WorldInputCmdProcessor::evalLeftMButtonEvents(const MouseEvent &event)
         }
 
     } else if (event.event == MouseEvent::EVENT_DOWN) {
-        Objective *objective;
-        PlayerID player_id;
-	
-        player_id = PlayerInterface::getLocalPlayerID();
-        click_status = ObjectiveInterface::quearyObjectiveLocationStatus( world_pos, player_id, &objective );
+        Objective *objective = 0;
+        click_status = ObjectiveInterface::quearyObjectiveLocationStatus(
+            world_pos, PlayerInterface::getLocalPlayerIndex(), &objective);
 	
         if ( (click_status == _player_occupied_objective_found) ) {
             selection_box_active = false;
@@ -572,9 +568,10 @@ WorldInputCmdProcessor::evalLeftMButtonEvents(const MouseEvent &event)
             iXY temp;
             MouseInterface::getMousePosition( &temp.x, &temp.y );
             
-            Objective *objective;
-            PlayerID player_id = PlayerInterface::getLocalPlayerID();
-            int cs = ObjectiveInterface::quearyObjectiveLocationStatus( world_pos, player_id, &objective );
+            Objective *objective = 0;
+            int cs = ObjectiveInterface::quearyObjectiveLocationStatus(
+                    world_pos, PlayerInterface::getLocalPlayerIndex(),
+                    &objective);
             
             if ( (cs == _player_occupied_objective_found) 
                     && outpost_goal_selection == objective->objective_state.ID
@@ -829,7 +826,7 @@ WorldInputCmdProcessor::sendAllianceRequest(const iXY& world_pos, bool make_brea
     if ( target_list.isSelected() == true ) {
         target_ptr = UnitInterface::getUnit( target_list.unit_list[0] );
 
-        uint8_t type;
+        Uint8 type;
         if ( make_break ) {
             type = _player_make_alliance;
         } else {
@@ -902,7 +899,7 @@ WorldInputCmdProcessor::draw()
         WorldViewInterface::worldXYtoClientXY(world_win, box_press, &box1);
         WorldViewInterface::worldXYtoClientXY(world_win, box_release, &box2);
 
-        screen->drawRect(box1, box2, Color::white);
+        screen->drawRect(iRect(box1, box2), Color::white);
     }
 
     if (outpost_goal_selection != -1) {
