@@ -21,13 +21,12 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "Util/Endian.hpp"
 #include "MapFile.hpp"
 #include "WadMapTable.hpp"
-#include <stdint.h>
 #include <string>
 
 class WorldMap
 {
 public:
-    typedef uint16_t MapElementType;
+    typedef Uint16 MapElementType;
     
     WorldMap();
     ~WorldMap();
