@@ -37,7 +37,7 @@ GameConfig::GameConfig(const std::string& configfile, bool usePhysFS)
       serverConnect("serverconnect", ""),
     
       playername("name", "Player"),
-      masterservers("masterservers", "81.173.119.122,81.169.185.36"),
+      masterservers("masterservers", "masterserver.netpanzer.org, masterserver2.netpanzer.org, masterserver.netpanzer.info"),
       
       serverport("serverport", NETPANZER_DEFAULT_PORT_TCP,0,65535),
       proxyserver("proxyserver",""),
@@ -58,6 +58,7 @@ GameConfig::GameConfig(const std::string& configfile, bool usePhysFS)
       windspeed("windspeed", 30),
       map("map", "Bad Neuburg"),
       mapcycle("mapcycle", "Cramped, Tight Quarters, Two Villages"),
+      motd("motd",""),
       logging("logging", false),
       publicServer("public", true),
       
@@ -68,6 +69,9 @@ GameConfig::GameConfig(const std::string& configfile, bool usePhysFS)
       displayshadows("displayshadows", true),
       blendsmoke("blendsmoke", true),
       screengamma("gamma", 50, 0, 100),
+#ifdef _WIN32
+      usedirectx("usedirectx", true),
+#endif
 
       enablesound("enable", true),
       enablemusic("music", true),
@@ -104,7 +108,18 @@ GameConfig::GameConfig(const std::string& configfile, bool usePhysFS)
       radar_enemyoutpostcolor("enemyoutpostcolor", _color_red, 0, _color_last-1),
       radar_unitsize("unitsize", _mini_map_unit_size_small, 0, _mini_map_unit_size_last-1),
       radar_objectivedrawmode("objectivedrawmode", _mini_map_objective_draw_mode_outline_rect, 0, _mini_map_objective_draw_mode_last-1),
-      radar_resizerate("resizerate", 400, 10, 1000)      
+      radar_resizerate("resizerate", 400, 10, 1000),
+      
+      titan("titan",2),
+      manta("manta",2),
+      panther1("panther1",2),
+      stinger("stinger",1),
+      spanzer("spanzer",2),
+      bobcat("bobcat",0),
+      wolf("wolf",0),
+      bear("bear",0),
+      drake("drake",0),
+      archer("archer",0)
 {
     this->configfile = configfile;
     this->usePhysFS = usePhysFS;
@@ -133,6 +148,7 @@ GameConfig::GameConfig(const std::string& configfile, bool usePhysFS)
     serversettings.push_back(&windspeed);
     //serversettings.push_back(&map);
     serversettings.push_back(&mapcycle);
+    serversettings.push_back(&motd);
     serversettings.push_back(&logging);
     serversettings.push_back(&publicServer);
    
@@ -143,6 +159,9 @@ GameConfig::GameConfig(const std::string& configfile, bool usePhysFS)
     visualssettings.push_back(&displayshadows);
     visualssettings.push_back(&blendsmoke);
     visualssettings.push_back(&screengamma);
+#ifdef _WIN32
+    visualssettings.push_back(&usedirectx);
+#endif
 
     soundsettings.push_back(&enablesound);
     soundsettings.push_back(&enablemusic);
@@ -180,6 +199,17 @@ GameConfig::GameConfig(const std::string& configfile, bool usePhysFS)
     radarsettings.push_back(&radar_objectivedrawmode);
     radarsettings.push_back(&radar_resizerate);
     
+    spawnsettings.push_back(&titan);
+    spawnsettings.push_back(&manta);
+    spawnsettings.push_back(&panther1);
+    spawnsettings.push_back(&stinger);
+    spawnsettings.push_back(&spanzer);
+    spawnsettings.push_back(&bobcat);
+    spawnsettings.push_back(&wolf);
+    spawnsettings.push_back(&bear);
+    spawnsettings.push_back(&drake);
+    spawnsettings.push_back(&archer);
+    
     try {
         loadConfig();
     } catch(std::exception& e) {
@@ -210,11 +240,17 @@ void GameConfig::loadConfig()
 
     loadSettings(inifile.getSection("game"), gamesettings);
     loadSettings(inifile.getSection("player"), playersettings);
+    if (playername.c_str()[0]==0) {
+        std::stringstream default_player;
+        default_player << "Player" << (rand()%1000);
+        playername=default_player.str();
+    }
     loadSettings(inifile.getSection("visuals"), visualssettings);
     loadSettings(inifile.getSection("sound"), soundsettings);
     loadSettings(inifile.getSection("interface"), interfacesettings);
     loadSettings(inifile.getSection("radar"), radarsettings);
     loadSettings(inifile.getSection("server"), serversettings);
+    loadSettings(inifile.getSection("spawnconfig"),spawnsettings);
 }
 
 void GameConfig::loadSettings(const INI::Section& section,
@@ -227,13 +263,16 @@ void GameConfig::loadSettings(const INI::Section& section,
 
             try {
                 ConfigInt* confint = dynamic_cast<ConfigInt*> (var);
-                if(confint)
+                if(confint) {
                     *confint = section.getIntValue(confint->getName());
+                    continue;
+                }
 
                 ConfigXY* confxy = dynamic_cast<ConfigXY*> (var);
                 if(confxy) {
                     confxy->set(section.getIntValue(confxy->getName() + "_x"),
                             section.getIntValue(confxy->getName() + "_y"));
+                    continue;
                 }
 
                 ConfigBool* confbool = dynamic_cast<ConfigBool*> (var);
@@ -247,14 +286,23 @@ void GameConfig::loadSettings(const INI::Section& section,
                     else
                         throw Exception("No boolean value for setting '%s'.",
                                         confbool->getName().c_str());
+                    continue;
                 }
 
+                ConfigStringSpecialChars* confstringspecial = dynamic_cast<ConfigStringSpecialChars*> (var);
+                if(confstringspecial) {
+                    *confstringspecial = section.getValue(confstringspecial->getName());
+                    continue;
+                }
+                
                 ConfigString* confstring = dynamic_cast<ConfigString*> (var);
                 if(confstring)
                     *confstring = section.getValue(confstring->getName());
 
+
                 // we have a value from config file in the variable now
-                var->setNonDefaultValue();
+                //var->setNonDefaultValue();
+                // now each subclass changethis if the value has been changed
             } catch(std::exception& e) {
                 LOG(("Skipping config '%s': %s", var->getName().c_str(),
                             e.what()));
@@ -277,6 +325,7 @@ void GameConfig::saveConfig()
     saveSettings(inifile.getSection("interface"), interfacesettings);
     saveSettings(inifile.getSection("radar"), radarsettings);
     saveSettings(inifile.getSection("server"), serversettings);
+    saveSettings(inifile.getSection("spawnconfig"),spawnsettings);
 
     if(usePhysFS) {
         OFileStream out (configfile);
