@@ -20,7 +20,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #include <assert.h>
 #include <string.h>
-#include <stdint.h>
 #include <vector>
 #include <string>
 
@@ -114,7 +113,7 @@ public:
     ConfigString    serverConnect;      // server to connect to
 
     // player settings
-    ConfigString playername;
+    ConfigStringSpecialChars playername;
     ConfigString masterservers;
 
     // server settings
@@ -136,6 +135,7 @@ public:
     ConfigInt    windspeed;
     ConfigString map;
     ConfigString mapcycle;
+    ConfigString motd;
     ConfigBool   logging;
     ConfigBool   publicServer;
 
@@ -147,6 +147,9 @@ public:
     ConfigBool  displayshadows;
     ConfigBool  blendsmoke;
     ConfigInt   screengamma;
+#ifdef _WIN32
+    ConfigBool  usedirectx;
+#endif
 
     // sound settings
     ConfigBool  enablesound;
@@ -187,6 +190,20 @@ public:
     ConfigInt   radar_unitsize;
     ConfigInt   radar_objectivedrawmode;
     ConfigInt   radar_resizerate;
+    
+    // spawnconfig settings
+    ConfigInt   titan;
+    ConfigInt   manta;
+    ConfigInt   panther1;
+    ConfigInt   stinger;
+    ConfigInt   spanzer;
+    ConfigInt   bobcat;
+    ConfigInt   wolf;
+    ConfigInt   bear;
+    ConfigInt   drake;
+    ConfigInt   archer;
+    
+    
 
     PlayerUnitConfig unit_spawn_config;
     
@@ -204,6 +221,7 @@ public:
         return( "Unknown" );
     }
 
+
     int GetUnitsPerPlayer() const
     {
         return maxunits / maxplayers;
@@ -319,7 +337,8 @@ private:
     std::vector<ConfigVariable*> visualssettings;
     std::vector<ConfigVariable*> soundsettings;
     std::vector<ConfigVariable*> interfacesettings;
-    std::vector<ConfigVariable*> radarsettings;    
+    std::vector<ConfigVariable*> radarsettings;   
+    std::vector<ConfigVariable*> spawnsettings;
 };
 
 extern GameConfig* gameconfig;
