@@ -17,7 +17,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 #include <config.h>
 
-#include <SDL.h>
+#include "SDL.h"
 
 #include "MouseInterface.hpp"
 #include "Util/FileSystem.hpp"
