@@ -25,14 +25,13 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "PlayerNetMessage.hpp"
 #include "Server.hpp"
 #include "NetworkServer.hpp"
+#include "Util/Log.hpp"
 
 #include "ConsoleInterface.hpp"
 // for UNIT_FLAGS_SURFACE
 #include "SelectionBoxSprite.hpp"
 
 // ** PlayerInterface Statics
-PlayerState PlayerInterface::local_player_state;
-
 PlayerState   *PlayerInterface::player_lists = 0;
 unsigned short PlayerInterface::max_players = 0;
 bool *      PlayerInterface::alliance_matrix = 0;
@@ -69,9 +68,6 @@ void PlayerInterface::initialize(unsigned short maxPlayers)
         player_lists[ player_index ].setName( temp_str );
     }
 
-    local_player_state.setPlayerID( PlayerID( 0xFFFF, 0xFFFFFFFF ) );
-    local_player_state.setStatus( _player_state_allocated );
-
     delete[] alliance_matrix;
     alliance_matrix = new bool [max_players * max_players];
     resetAllianceMatrix();
@@ -234,15 +230,15 @@ int PlayerInterface::getActivePlayerCount()
     return( count );
 }
 
-PlayerState * PlayerInterface::allocateLoopBackPlayer()
+PlayerState* PlayerInterface::allocateLoopBackPlayer()
 {
     local_player_index = 0;
 
     SDL_mutexP(mutex);
-    player_lists[ local_player_index ].setStatus( _player_state_active );
+    player_lists[local_player_index].setStatus(_player_state_active);
     SDL_mutexV(mutex);
 
-    return( &player_lists[ local_player_index ] );
+    return &player_lists[local_player_index];
 }
 
 int PlayerInterface::countPlayers()
@@ -287,15 +283,13 @@ void PlayerInterface::spawnPlayer( unsigned short player_index, const iXY &locat
 
 void PlayerInterface::spawnPlayer( const PlayerID &player, const iXY &location )
 {
-    unsigned short player_index;
-
-    player_index = player.getIndex();
+    Uint16 player_index = player.getIndex();
     assert( player_index < max_players );
 
     SDL_mutexP(mutex);
-    if ( player_lists[ player_index ].getStatus() != _player_state_free ) {
-        UnitInterface::spawnPlayerUnits( location,
-                                         player,
+    if ( player_lists[player_index].getStatus() != _player_state_free ) {
+        UnitInterface::spawnPlayerUnits(location,
+                                         player_index,
                                          player_lists[ player_index ].unit_config
                                        );
     } // ** if _player_state_active
@@ -417,11 +411,14 @@ void PlayerInterface::netMessageConnectID(const NetMessage* message)
         = (const PlayerConnectID *) message;
 
     local_player_index = connect_mesg->connect_state.getPlayerIndex();
+    if(local_player_index >= max_players) {
+        LOGGER.warning("Invalide netMessageConnectID Message");
+        return;
+    }
 
     SDL_mutexP(mutex);
     player_lists[local_player_index].setFromNetworkPlayerState
         (&connect_mesg->connect_state);
-    //forceUniquePlayerFlags();
     SDL_mutexV(mutex);
 }
 
@@ -429,59 +426,31 @@ void PlayerInterface::netMessageSyncState(const NetMessage* message)
 {
     const PlayerStateSync *sync_mesg
         = (const PlayerStateSync *) message;
-    uint16_t player_index = sync_mesg->player_state.getPlayerIndex();
+    Uint16 player_index = sync_mesg->player_state.getPlayerIndex();
+
+    if(player_index >= max_players) {
+        LOGGER.warning("Malformed MessageSyncState message");
+        return;
+    }
+    
     SDL_mutexP(mutex);
     player_lists[player_index].setFromNetworkPlayerState(&sync_mesg->player_state);
-    forceUniquePlayerFlags();
     SDL_mutexV(mutex);
 }
 
-void PlayerInterface::forceUniquePlayerFlags()
-{
-    // make sure our own flag stays the same (TODO: avoid copy&paste here...)
-    PlayerState& player1 = player_lists[local_player_index];
-    bool unique;
-    do {
-        unique = true;
-        for(int player_id2 = local_player_index-1; player_id2>=0;--player_id2) {
-            const PlayerState& player2 = player_lists[player_id2];
-            if(player1.getFlag() == player2.getFlag()) {
-                unique = false;
-                uint16_t newflag = player1.getFlag() + 1;
-                if(newflag >= UNIT_FLAGS_SURFACE.getFrameCount())
-                    newflag = 0;
-                player1.setFlag(newflag);
-                break;
-            }
-        }
-    } while(!unique);                                                      
-    
-    // make sure each player has a unique flag
-    for(uint16_t player_id = 0; player_id < max_players; ++player_id) {
-        PlayerState& player1 = player_lists[player_id];
-        bool unique;
-        do {
-            unique = true;
-            for(int player_id2 = player_id-1; player_id2>=0;--player_id2) {
-                const PlayerState& player2 = player_lists[player_id2];
-                if(player1.getFlag() == player2.getFlag()) {
-                    unique = false;
-                    uint16_t newflag = player1.getFlag() + 1;
-                    if(newflag >= UNIT_FLAGS_SURFACE.getFrameCount())
-                        newflag = 0;
-                    player1.setFlag(newflag);
-                    break;
-                }
-            }
-        } while(!unique);
-    }
-}
-
 void PlayerInterface::netMessageScoreUpdate(const NetMessage *message)
 {
     const PlayerScoreUpdate* score_update 
         = (const PlayerScoreUpdate *) message;
 
+    if(score_update->getKillByPlayerIndex() >= PlayerInterface::getMaxPlayers()
+            || score_update->getKillOnPlayerIndex() 
+            >= PlayerInterface::getMaxPlayers())
+    {
+        LOGGER.warning("Malformed scrore update packet.");
+        return;
+    }
+
     PlayerState* player1 = getPlayer(score_update->getKillByPlayerIndex());
     PlayerState* player2 = getPlayer(score_update->getKillOnPlayerIndex());
     setKill(player1, player2, (UnitType) score_update->unit_type );
@@ -494,6 +463,12 @@ void PlayerInterface::netMessageAllianceRequest(const NetMessage *message)
     const PlayerAllianceRequest *allie_request
         = (const PlayerAllianceRequest *) message;
 
+    if(allie_request->getAllieByPlayerIndex() >= max_players
+       || allie_request->getAllieWithPlayerIndex() >= max_players) {
+        LOGGER.warning("Invalid alliance request message");
+        return;                                                       
+    }
+
     SDL_mutexP(mutex);
     if ( allie_request->alliance_request_type == _player_make_alliance ) {
         setAlliance(
@@ -548,6 +523,12 @@ void PlayerInterface::netMessageAllianceUpdate(const NetMessage* message)
     const PlayerAllianceUpdate* allie_update
         = (const PlayerAllianceUpdate *) message;
 
+    if(allie_update->getAllieByPlayerIndex() >= max_players
+       || allie_update->getAllieWithPlayerIndex() >= max_players) {
+        LOGGER.warning("Invalid alliance update message");
+        return;
+    }
+
     SDL_mutexP(mutex);
     if (allie_update->alliance_update_type == _player_make_alliance) {
         setAlliance(
@@ -644,3 +625,17 @@ void PlayerInterface::disconnectPlayerCleanup(const PlayerID &player_id )
     SERVER->sendMessage(&player_state_update, sizeof(PlayerStateSync));
 }
 
+PlayerState*
+PlayerInterface::getPlayerByNetworkID(NetClientID id)
+{
+    for(int i = 0; i < max_players; ++i) {
+        PlayerState* state = &player_lists[i];
+        if(state->getStatus() != _player_state_active)
+            continue;
+        if(state->getNetworkID() == id)
+            return state;
+    }
+
+    return 0;
+}
+
