@@ -48,6 +48,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #include "UnitMessageTypes.hpp"
 #include "PlayerNetMessage.hpp"
+#include "NetPacket.hpp"
+#include "TerminalNetMesg.hpp"
 
 #include "System/Sound.hpp"
 #include "ParticleInterface.hpp"
@@ -102,6 +104,7 @@ void UnitInterface::initialize( unsigned long max_units )
 
 void UnitInterface::cleanUp()
 {
+    // XXX why doesn't clean the unit_bucket_array?
     delete[] playerUnitLists;
     playerUnitLists = 0;
 
@@ -110,7 +113,8 @@ void UnitInterface::cleanUp()
     units.clear();
 }
 
-void UnitInterface::reset()
+void
+UnitInterface::reset()
 {
     for(size_t i = 0; i < max_players; i++ ) {
         playerUnitLists[i].clear();
@@ -123,20 +127,59 @@ void UnitInterface::reset()
     units.clear();
 }
 
-void UnitInterface::sendMessage(const UnitMessage* message)
+void
+UnitInterface::processNetPacket(const NetPacket* packet)
+{
+    const NetMessage* message = packet->getNetMessage();
+    const TerminalUnitCmdRequest* terminal_command =
+        (const TerminalUnitCmdRequest*) message;
+
+    const PlayerState* player 
+        = PlayerInterface::getPlayerByNetworkID(packet->fromID);
+    if(player == 0) {
+        LOGGER.warning("No player found for Network ID '%u'?!?",
+                packet->fromID);
+        return;
+    }
+    
+    sendMessage(&(terminal_command->comm_request) , player);
+}
+
+void
+UnitInterface::sendMessage(const UnitMessage* message,const PlayerState* player)
 {
     if (message->isFlagged(_umesg_flag_unique)) {
         UnitBase* unit = getUnit(message->getUnitID());
         if(unit == 0)
             return;
-
+        if(player && unit->player != player) {
+            LOGGER.warning(
+                "Terminal request for unit (%u) not owned by player (%u).\n",
+                unit->id, player->getID());
+            return;
+        }
+                    
         unit->processMessage(message);
     } else if (message->isFlagged( _umesg_flag_broadcast) ) {
+        if(message->message_id != _umesg_weapon_hit) {
+            LOGGER.warning("Broadcast flag only allowed for weapon hit.");
+            if(player) {
+                LOGGER.warning("from player %u.\n", player->getID());
+            }
+            return;
+        }
+            
         for(Units::iterator i = units.begin(); i != units.end(); ++i) {
             UnitBase* unit = i->second;
             unit->processMessage(message);
         }
     } else if (message->isFlagged( _umesg_flag_manager_request) ) {
+        if(player) {
+            LOGGER.warning(
+                    "UnitManagerMessage sent out by player %u not allowed.",
+                    player->getID());
+            return;
+        }
   	processManagerMessage(message);
     }
 }
@@ -320,7 +363,7 @@ void UnitInterface::addNewUnit(UnitBase *unit)
 {
     units.insert(std::make_pair(unit->id, unit));
    
-    uint16_t player_index = unit->player->getID();
+    Uint16 player_index = unit->player->getID();
     playerUnitLists[player_index].push_back(unit);
 
     unit_bucket_array.addUnit(unit);
@@ -373,15 +416,12 @@ UnitInterface::getUnit(UnitID id)
 // ******************************************************************
 UnitBase* UnitInterface::createUnit( unsigned short unit_type,
                                       const iXY &location,
-                                      const PlayerID &player
-                                    )
+                                      Uint16 player_id)
 {
-    uint16_t player_index = player.getIndex();
-
-    if (playerUnitLists[player_index].size() >= units_per_player)
+    if (playerUnitLists[player_id].size() >= units_per_player)
 	return 0;
 
-    UnitBase* unit = newUnit(unit_type, location, player_index, newUnitID());
+    UnitBase* unit = newUnit(unit_type, location, player_id, newUnitID());
     addNewUnit(unit);
 
     return unit;
@@ -390,7 +430,7 @@ UnitBase* UnitInterface::createUnit( unsigned short unit_type,
 // ******************************************************************
 
 void UnitInterface::spawnPlayerUnits(const iXY &location,
-                                     const PlayerID &player,
+                                     Uint16 player_id,
                                      const PlayerUnitConfig &unit_config)
 {
     iXY next_loc;
@@ -408,7 +448,7 @@ void UnitInterface::spawnPlayerUnits(const iXY &location,
         unit_spawn_count = unit_config.getSpawnUnitCount( unit_type_index );
         for ( unit_spawn_index = 0; unit_spawn_index < unit_spawn_count; unit_spawn_index++ ) {
             unit_placement_matrix.getNextEmptyLoc( &next_loc );
-            unit = createUnit( unit_type_index, next_loc, player );
+            unit = createUnit(unit_type_index, next_loc, player_id);
 
             assert(unit != 0);
             UnitRemoteCreate create_mesg(unit->player->getID(), unit->id,
@@ -424,7 +464,7 @@ void UnitInterface::spawnPlayerUnits(const iXY &location,
 
 void
 UnitInterface::queryUnitsAt(std::vector<UnitID>& working_list,
-        const iXY& point, uint16_t player_id, unsigned char search_flags)
+        const iXY& point, Uint16 player_id, unsigned char search_flags)
 {
     for(Units::iterator i = units.begin(); i != units.end(); ++i) {
         UnitBase* unit = i->second;
@@ -446,7 +486,7 @@ UnitInterface::queryUnitsAt(std::vector<UnitID>& working_list,
 
 void
 UnitInterface::queryUnitsAt(std::vector<UnitID>& working_list,
-        const iRect& rect, uint16_t player_id, unsigned char search_flags)
+        const iRect& rect, Uint16 player_id, unsigned char search_flags)
 {
     for(Units::iterator i = units.begin(); i != units.end(); ++i) {
         UnitBase* unit = i->second;
@@ -467,7 +507,7 @@ UnitInterface::queryUnitsAt(std::vector<UnitID>& working_list,
 /****************************************************************************/
 
 bool UnitInterface::queryClosestUnit( UnitBase **closest_unit_ptr,
-                                       iXY &loc, uint16_t player_id,
+                                       iXY &loc, Uint16 player_id,
                                        unsigned char search_flags )
 {
     long closest_magnitude = 0;
@@ -561,14 +601,14 @@ bool UnitInterface::queryClosestUnit( UnitBase **closest_unit_ptr, iRect &boundi
 // ******************************************************************
 
 bool UnitInterface::queryClosestEnemyUnit(UnitBase **closest_unit_ptr,
-        iXY &loc, uint16_t player_index)
+        iXY &loc, Uint16 player_index)
 {
     UnitBase *closest_unit = 0;
     long closest_magnitude = 0;
 
     for(Units::iterator i = units.begin(); i != units.end(); ++i) {
         UnitBase* unit = i->second;
-        uint16_t unitPlayerID = unit->player->getID();
+        Uint16 unitPlayerID = unit->player->getID();
         
         if(unitPlayerID == player_index
                 || PlayerInterface::isAllied(player_index, unitPlayerID))
@@ -605,7 +645,7 @@ bool UnitInterface::queryClosestEnemyUnit(UnitBase **closest_unit_ptr,
 
 unsigned char UnitInterface::queryUnitLocationStatus(iXY loc)
 {
-    uint16_t player_id = PlayerInterface::getLocalPlayerIndex();
+    Uint16 player_id = PlayerInterface::getLocalPlayerIndex();
 
     std::vector<UnitID> locUnits;
     queryUnitsAt(locUnits, loc, player_id, 0);
@@ -654,10 +694,14 @@ void UnitInterface::processManagerMessage(const UnitMessage* message)
 {
     switch(message->message_id) {
         case _umesg_end_lifecycle:
-            unitManagerMesgEndLifecycle( message );
+            unitManagerMesgEndLifecycle(message);
             break;
         default:
+            LOGGER.warning("Unknown unit Manage Message type (%u).",
+                    message->message_id);
+#ifdef DEBUG
             assert(false);
+#endif
     }
 }
 
@@ -712,12 +756,21 @@ void UnitInterface::unitSyncMessage(const NetMessage *net_message)
     const UnitIniSyncMessage* sync_message 
         = (const UnitIniSyncMessage *) net_message;
 
-    UnitBase* unit = newUnit(sync_message->unit_type,
-            iXY(sync_message->getLocX(), sync_message->getLocY()),
-            sync_message->getPlayerID(), sync_message->getUnitID());
-
-    unit->in_sync_flag = false;
-    addNewUnit(unit);
+    try {
+        std::map<UnitID, UnitBase*>::iterator uit = units.find(sync_message->getUnitID());
+        if ( uit != units.end() ) {
+            LOGGER.warning("UnitInterface::unitSyncMessage() Received an existing unit [%d]",
+                            sync_message->getUnitID());
+            return;
+        }
+        UnitBase* unit = newUnit(sync_message->unit_type,
+                iXY(sync_message->getLocX(), sync_message->getLocY()),
+                sync_message->getPlayerID(), sync_message->getUnitID());
+        unit->in_sync_flag = false;
+        addNewUnit(unit);
+    } catch(std::exception& e) {
+        LOGGER.warning("UnitInterface::unitSyncMessage() Couldn't sync unit '%s'", e.what());
+    }
 }
 
 // ******************************************************************
@@ -761,14 +814,23 @@ void UnitInterface::unitCreateMessage(const NetMessage* net_message)
     const UnitRemoteCreate* create_mesg 
         = (const UnitRemoteCreate *) net_message;
 
-    uint16_t player_index = create_mesg->getPlayerID();
+    Uint16 player_index = create_mesg->getPlayerID();
 
-    UnitBase* unit = newUnit(create_mesg->unit_type,
-            iXY(create_mesg->getLocX(), create_mesg->getLocY()),
-            player_index,
-            create_mesg->getUnitID());
-
-    addNewUnit(unit);
+    try {
+        std::map<UnitID, UnitBase*>::iterator uit = units.find(create_mesg->getUnitID());
+        if ( uit != units.end() ) {
+            LOGGER.warning("UnitInterface::unitCreateMessage() Received an existing unit [%d]",
+                            create_mesg->getUnitID());
+            return;
+        }
+        UnitBase* unit = newUnit(create_mesg->unit_type,
+                iXY(create_mesg->getLocX(), create_mesg->getLocY()),
+                player_index,
+                create_mesg->getUnitID());
+        addNewUnit(unit);
+    } catch(std::exception& e) {
+        LOGGER.warning("UnitInterface::unitSyncMessage() Couldn't create new unit '%s'", e.what());
+    }
 }
 
 // ******************************************************************
@@ -803,13 +865,18 @@ void UnitInterface::processNetMessage(const NetMessage* net_message)
             break;
 
         default:
+            LOGGER.warning("Unknown message id in UnitMessage (%d)",
+                    net_message->message_id);
+#ifdef DEBUG
             assert(false);
+#endif
+            break;
     }
 }
 
 // ******************************************************************
 
-void UnitInterface::destroyPlayerUnits(uint16_t player_id)
+void UnitInterface::destroyPlayerUnits(Uint16 player_id)
 {
     UMesgSelfDestruct self_destruct;
     self_destruct.setHeader(0, _umesg_flag_unique);
