@@ -25,9 +25,18 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "NetworkClientUnix.hpp"
 #include "LobbyView.hpp"
 
-// #define NETWORKDEBUG
+#include "Desktop.hpp"
+#include "DisconectedView.hpp"
 
-NetworkClientUnix::NetworkClientUnix( void )
+#include "Network/SocketManager.hpp"
+
+//#define NETWORKDEBUG
+
+#ifdef NETWORKDEBUG
+#include "NetPacketDebugger.hpp"
+#endif
+
+NetworkClientUnix::NetworkClientUnix()
         : NetworkClient(), clientsocket(0)
 {}
 
@@ -36,14 +45,33 @@ NetworkClientUnix::~NetworkClientUnix()
     delete clientsocket;
 }
 
-int NetworkClientUnix::joinServer(const std::string& server_name)
+void
+NetworkClientUnix::onClientConnected(ClientSocket *s)
 {
+    (void)s;
+}
+
+void
+NetworkClientUnix::onClientDisconected(ClientSocket *s, const char *msg)
+{
+    (void)s;
+    DisconectedView *dv = (DisconectedView *)Desktop::getView("DisconectedView");
+    dv->setMsg(msg);
+    Desktop::setVisibility("DisconectedView", true);
     delete clientsocket;
+    clientsocket=0;
+}
+
+bool NetworkClientUnix::joinServer(const std::string& server_name)
+{
+    if ( clientsocket )
+        delete clientsocket;
     clientsocket = 0;
+    
     LOG( ("Trying to join server '%s'.\n", server_name.c_str()) );
     try {
-        clientsocket = new ClientSocket(server_name);
-    } catch(Exception e) {
+        clientsocket = new ClientSocket(this, server_name);
+    } catch(std::exception& e) {
         LOG( ( "Couldn't connect to server:\n%s.", e.what()) );
         char text[128];
         snprintf(text, 128, "connection error: %s", e.what());
@@ -56,20 +84,25 @@ int NetworkClientUnix::joinServer(const std::string& server_name)
     return true;
 }
 
-int NetworkClientUnix::partServer()
+void NetworkClientUnix::partServer()
 {
-    delete clientsocket;
+    if ( clientsocket )
+        delete clientsocket;
     clientsocket = 0;
-
-    return true;
 }
 
-void NetworkClientUnix::sendMessage(NetMessage *message, size_t size, int flags)
+void NetworkClientUnix::sendMessage(NetMessage* message, size_t size)
 {
-    if ( connection_type == _connection_loop_back ) {
+    message->setSize(size);
+    
+    if (connection_type == _connection_loop_back) {
+        net_packet.fromID = 0;
+        net_packet.toID = 0;
         memcpy(net_packet.data, message, size);
-        net_packet.packet_size = (unsigned short) size;
-        loop_back_recv_queue.enqueue( net_packet );
+        loop_back_recv_queue.enqueue(net_packet);
+#ifdef NETWORKDEBUG
+        NetPacketDebugger::logMessage("LS", message);
+#endif
         return;
     }
 
@@ -77,46 +110,39 @@ void NetworkClientUnix::sendMessage(NetMessage *message, size_t size, int flags)
         return;
 
 #ifdef NETWORKDEBUG
-    LOG( ( "SEND >> Class: %d ID: %d", message->message_class,
-           message->message_id) );
+    NetPacketDebugger::logMessage("S", message);
 #endif
 
-    message->size = size;
-    clientsocket->sendMessage((char*) message, message->size,
-                              ! (flags & _network_send_no_guarantee) );
+    clientsocket->sendMessage(message, size);
 
-    NetworkState::incPacketsSent( size );
+    NetworkState::incPacketsSent(size);
 }
 
-int NetworkClientUnix::getMessage(NetMessage *message)
+bool NetworkClientUnix::getMessage(NetMessage *message)
 {
-    updateKeepAliveState();
-
-    if ( receive_queue.isReady() ) {
-        receive_queue.dequeue( &net_packet );
-
-        memcpy(message, net_packet.data, net_packet.packet_size);
+    if(clientsocket == 0)
+        return false;
+    if(!receive_queue.isReady())
+        return false;
+    
+    receive_queue.dequeue( &net_packet );
+    memcpy(message, net_packet.data, net_packet.getSize());
 
 #ifdef NETWORKDEBUG
-        LOG( ( "RECV >> Class: %d ID: %d", message->message_class,
-               message->message_id) );
+    NetPacketDebugger::logMessage("R", message);
 #endif
 
-        if ( message->message_class == _net_message_class_client_server ) {
-            processNetMessage( message );
-        }
-
-        NetworkState::incPacketsReceived( net_packet.packet_size );
-
-        return true;
+    if ( message->message_class == _net_message_class_client_server ) {
+        processNetMessage( message );
     }
 
-    return false;
+    NetworkState::incPacketsReceived(net_packet.getSize());
+
+    return true;
 }
 
 void NetworkClientUnix::checkIncoming()
 {
-    if(clientsocket) {
-        clientsocket->read();
-    }
+   
+    
 }
