@@ -15,27 +15,32 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
-#ifndef _NETWORK_CLIENT_WINSOCK_HPP
-#define _NETWORK_CLIENT_WINSOCK_HPP
+#ifndef _NETWORK_CLIENT_UNIX_HPP
+#define _NETWORK_CLIENT_UNIX_HPP
 
 #include "NetworkClient.hpp"
 #include "Network/ClientSocket.hpp"
 
-class NetworkClientUnix : public NetworkClient
+class NetworkClientUnix : public NetworkClient, public ClientSocketObserver
 {
 public:
     NetworkClientUnix();
     virtual ~NetworkClientUnix();
 
-    virtual int joinServer(const std::string& server_name);
-    virtual int partServer();
+    virtual bool joinServer(const std::string& server_name);
+    virtual void partServer();
 
-    virtual void sendMessage(NetMessage *message, size_t size, int flags);
-    virtual int getMessage(NetMessage *message);
+    virtual void sendMessage(NetMessage* message, size_t size);
+    void sendRemaining() { if ( clientsocket ) clientsocket->sendRemaining(); };
+    virtual bool getMessage(NetMessage *message);
 
     virtual void checkIncoming();
+protected:
+    void onClientConnected(ClientSocket *s);
+    void onClientDisconected(ClientSocket *s, const char *msg);    
+    
 private:
     ClientSocket* clientsocket;
 };
 
-#endif // ** _NETWORK_CLIENT_WINSOCK_HPP
+#endif
