@@ -35,20 +35,21 @@ NetworkServerUnix::NetworkServerUnix()
 
 NetworkServerUnix::~NetworkServerUnix()
 {
-    delete serversocket;
+    if ( serversocket )
+        delete serversocket;
 }
 
 std::string
-NetworkServerUnix::getIP(SocketClient::ID id) const
+NetworkServerUnix::getIP(NetClientID id) const
 {
     return serversocket->getClientIP(id);
 }
 
 void
-NetworkServerUnix::shutdownClientTransport(SocketClient::ID client_id)
+NetworkServerUnix::shutdownClientTransport(NetClientID client_id)
 {
-    assert(serversocket != 0);
-    serversocket->removeClient(client_id);
+    if (serversocket)
+        serversocket->disconectClient(client_id);
 }
 
 void
@@ -58,7 +59,10 @@ NetworkServerUnix::openSession()
 void
 NetworkServerUnix::hostSession()
 {
-    delete serversocket;
+    if ( serversocket ) {
+        delete serversocket;
+        serversocket = 0;
+    }
     serversocket = new ServerSocket(gameconfig->bindaddress,
             gameconfig->serverport);
 }
@@ -66,12 +70,13 @@ NetworkServerUnix::hostSession()
 void
 NetworkServerUnix::closeSession()
 {
-    delete serversocket;
+    if ( serversocket )
+        delete serversocket;
     serversocket = 0;
 }
 
 void
-NetworkServerUnix::sendMessage(SocketClient::ID network_id, NetMessage* message,
+NetworkServerUnix::sendMessage(NetClientID network_id, NetMessage* message,
         size_t size)
 {
     if(serversocket == 0)
@@ -143,7 +148,5 @@ void
 NetworkServerUnix::checkIncoming()
 {
     cleanupClients();
-    if(serversocket)
-        serversocket->read();
 }
 
