@@ -15,36 +15,40 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
-#ifndef _UNIXSERVER_H
-#define _UNIXSERVER_H
+#ifndef _SERVERSOCKET_H
+#define _SERVERSOCKET_H
 
-#include "ClientList.hpp"
+#include <map>
+#include "Network/TCPListenSocket.hpp"
+#include "ClientSocket.hpp"
 
-class BasicGameInfo;
+using namespace network;
+using namespace std;
 
-class ServerSocket
+class ServerSocket : public TCPListenSocketObserver, public ClientSocketObserver
 {
 public:
-    ServerSocket(Uint16 tcpport);
+    ServerSocket(const string& bindaddress, Uint16 port);
     ~ServerSocket();
 
-    void read();
-    void sendMessage(SocketClient::ID toclient, const char* data,
-            size_t datasize, bool realiable = true);
-    void removeClient(SocketClient::ID clientid);
+    void sendMessage(NetClientID toclient, const void* data,
+            size_t datasize);
+    void removeClient(NetClientID clientid);
+
+    string getClientIP(NetClientID);
+    void disconectClient(NetClientID c);
+    void sendRemaining();
 
 protected:
+    network::TCPSocketObserver * onNewConnection(TCPListenSocket *so,const Address &fromaddr);
+    void onClientConnected(ClientSocket *s);
+    void onClientDisconected(ClientSocket *s, const char * msg);
     friend class SocketClient;
-    void closeConnection(SocketClient* client);
 
 private:
-    void acceptNewClients();
-    void readTCP();
-    void readClientTCP(SocketClient* client);
+    TCPListenSocket * socket;
+    map<NetClientID, ClientSocket *> clients;
 
-    TCPsocket tcpsocket;
-    SDLNet_SocketSet sockets;
-    ClientList* clientlist;
 };
 
 #endif
