@@ -31,7 +31,7 @@ class FireParticle2D
 {
 public:
     float totalTime;
-    uint8_t  color;
+    Uint8  color;
     fXYZ  pos;
     bool  isAlive;
 
@@ -40,6 +40,8 @@ public:
     {
         reset();
     };
+	virtual ~FireParticle2D()
+	{ }
 
     void reset();
 
