@@ -25,8 +25,6 @@ PackedSurfaceList FlameParticle2D::staticPackedExplosion1;
 
 const int explosionFPS = 18;
 
-const char explosionPath[] = "pics/particles/explosion/";
-
 // FlameParticle2D
 //---------------------------------------------------------------------------
 FlameParticle2D::FlameParticle2D(	const fXYZ  &pos,
@@ -58,7 +56,7 @@ FlameParticle2D::FlameParticle2D(	const fXYZ  &pos,
 
     // Check for accelerated flames.
     packedSurface.setFPS(getFPS(explosionFPS, 0));
-}; // end FlameParticle2D::FlameParticle2D
+} // end FlameParticle2D::FlameParticle2D
 
 // loadPakFiles
 //---------------------------------------------------------------------------
