@@ -32,13 +32,15 @@ private:
     fXYZ  pos;
     float totalTime;
     float color;
-    uint8_t  size;
+    Uint8  size;
     float age;
-    uint8_t  lifetime;
+    Uint8  lifetime;
     float timeElapsedPeriod;
 
 public:
     SnowParticle2D();
+	virtual ~SnowParticle2D()
+	{ }
 
     void init(fXYZ pos, unsigned size);
     void reset();
