@@ -41,8 +41,8 @@ View     *Desktop::mouseView;
 View     *Desktop::prevMouseView;
 View     *Desktop::lMouseView;
 View     *Desktop::rMouseView;
-TIMESTAMP Desktop::lDoubleClickDeadline;
-TIMESTAMP Desktop::rDoubleClickDeadline;
+TimeStamp Desktop::lDoubleClickDeadline;
+TimeStamp Desktop::rDoubleClickDeadline;
 float     Desktop::doubleClickTime = 0.15f;
 int       Desktop::mouseMoveStatus = 0;
 
@@ -642,10 +642,9 @@ void DesktopView::doDraw(Surface &viewArea, Surface &clientArea)
 
 // rMouseDrag
 //---------------------------------------------------------------------------
-void DesktopView::rMouseDrag(const iXY &downPos, const iXY &prevPos, const iXY &newPos)
+void DesktopView::rMouseDrag(const iXY&, const iXY &prevPos, const iXY &newPos)
 {
     moveTo(min + newPos - prevPos);
-
 } // end DesktopView::rMouseDrag
 
 // doActivate
@@ -653,5 +652,4 @@ void DesktopView::rMouseDrag(const iXY &downPos, const iXY &prevPos, const iXY &
 void DesktopView::doActivate()
 {
     Desktop::setActiveView(this);
-
 } // end DesktopView::doActivate
