@@ -18,7 +18,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #ifndef __cMouse_hpp__
 #define __cMouse_hpp__
 
-#include <SDL.h>
+#include "SDL.h"
 
 #include "2D/Surface.hpp"
 #include "Types/iXY.hpp"
