@@ -128,7 +128,7 @@ void AreYouSureResignView::init()
     setAllowResize(false);
     setDisplayStatusBar(false);
 
-    resize(screen->getPix());
+    resize(screen->getWidth(), screen->getHeight());
     moveTo(0,0);
 
     int x = (getClientRect().getSize().x - (141 * 2 + 20)) / 2;
