@@ -200,32 +200,32 @@ void LibView::drawParticleInfo(Surface &dest, iXY pos)
 
     char strBuf[256];
 
-    dest.bltString(iXY(pos.x, pos.y), "-- Particle Info --", Color::green);
+    dest.bltString(pos.x, pos.y, "-- Particle Info --", Color::green);
     pos.y += yOffset;
 
-    dest.bltString(iXY(pos.x, pos.y), "This frame count", Color::yellow);
+    dest.bltString(pos.x, pos.y, "This frame count", Color::yellow);
     pos.y += yOffset;
 
     sprintf(strBuf, "Particle Systems: %d", ParticleSystem2D::getParticleSystemCount());
-    dest.bltString(iXY(pos.x + xOffset, pos.y), strBuf, Color::white);
+    dest.bltString(pos.x + xOffset, pos.y, strBuf, Color::white);
     pos.y += yOffset;
 
     sprintf(strBuf, "Particles:        %d", Particle2D::getFrameCount());
-    dest.bltString(iXY(pos.x + xOffset, pos.y), strBuf, Color::white);
+    dest.bltString(pos.x + xOffset, pos.y, strBuf, Color::white);
     pos.y += yOffset;
 
-    dest.bltString(iXY(pos.x, pos.y), "Peak count", Color::yellow);
+    dest.bltString(pos.x, pos.y, "Peak count", Color::yellow);
     pos.y += yOffset;
 
     sprintf(strBuf, "Particle Systems: %d", ParticleSystem2D::getPeakParticleSystemCount());
-    dest.bltString(iXY(pos.x + xOffset, pos.y), strBuf, Color::white);
+    dest.bltString(pos.x + xOffset, pos.y, strBuf, Color::white);
     pos.y += yOffset;
 
     sprintf(strBuf, "Particles:        %d", Particle2D::getPeakCount());
-    dest.bltString(iXY(pos.x + xOffset, pos.y), strBuf, Color::white);
+    dest.bltString(pos.x + xOffset, pos.y, strBuf, Color::white);
     pos.y += yOffset;
 
-    dest.bltString(iXY(pos.x, pos.y), "Crater info", Color::yellow);
+    dest.bltString(pos.x, pos.y, "Crater info", Color::yellow);
     pos.y += yOffset;
 
     float hitCount;
@@ -235,36 +235,36 @@ void LibView::drawParticleInfo(Surface &dest, iXY pos)
     hitCount  = CraterParticle2D::getCacheHitCount();
 
     sprintf(strBuf, "Cache Miss:                %d (%%%2.2f)", int(missCount), 100.0f * (missCount / (hitCount + missCount)));
-    dest.bltString(iXY(pos.x + xOffset, pos.y), strBuf, Color::white);
+    dest.bltString(pos.x + xOffset, pos.y, strBuf, Color::white);
     pos.y += yOffset;
 
     sprintf(strBuf, "Cache Hit:                 %d (%%%2.2f)", int(hitCount), 100.0f * (hitCount / (hitCount + missCount)));
-    dest.bltString(iXY(pos.x + xOffset, pos.y), strBuf, Color::white);
+    dest.bltString(pos.x + xOffset, pos.y, strBuf, Color::white);
     pos.y += yOffset;
 
     missCount = ParticleInterface::getExplosionFlameFlashCullMissCount();
     hitCount  = ParticleInterface::getExplosionFlameFlashCullHitCount();
 
-    dest.bltString(iXY(pos.x, pos.y), "Cull info", Color::yellow);
+    dest.bltString(pos.x, pos.y, "Cull info", Color::yellow);
     pos.y += yOffset;
 
     sprintf(strBuf, "Explosion Flame Flash Miss:%d (%%%2.2f)", int(missCount), 100.0f * (missCount / (hitCount + missCount)));
-    dest.bltString(iXY(pos.x + xOffset, pos.y), strBuf, Color::white);
+    dest.bltString(pos.x + xOffset, pos.y, strBuf, Color::white);
     pos.y += yOffset;
 
     sprintf(strBuf, "Explosion Flame Flash Hit: %d (%%%2.2f)", int(hitCount), 100.0f * (hitCount / (hitCount + missCount)));
-    dest.bltString(iXY(pos.x + xOffset, pos.y), strBuf, Color::white);
+    dest.bltString(pos.x + xOffset, pos.y, strBuf, Color::white);
     pos.y += yOffset;
 
     missCount = ParticleInterface::getMuzzleSystemCullMissCount();
     hitCount  = ParticleInterface::getMuzzleSystemCullHitCount();
 
     sprintf(strBuf, "Muzzle System Miss:        %d (%%%2.2f)", int(missCount), 100.0f * (missCount / (hitCount + missCount)));
-    dest.bltString(iXY(pos.x + xOffset, pos.y), strBuf, Color::white);
+    dest.bltString(pos.x + xOffset, pos.y, strBuf, Color::white);
     pos.y += yOffset;
 
     sprintf(strBuf, "Muzzle System Hit:         %d (%%%2.2f)", int(hitCount), 100.0f * (hitCount / (hitCount + missCount)));
-    dest.bltString(iXY(pos.x + xOffset, pos.y), strBuf, Color::white);
+    dest.bltString(pos.x + xOffset, pos.y, strBuf, Color::white);
     pos.y += yOffset;
 }
 
@@ -273,7 +273,7 @@ void LibView::drawParticleInfo(Surface &dest, iXY pos)
 void LibView::rMouseDrag(const iXY&, const iXY &prevPos, const iXY &newPos)
 {
     moveTo(min + newPos - prevPos);
-    checkArea(screen->getPix());
+    checkArea(iXY(screen->getWidth(),screen->getHeight()));
 }
 
 // doActivate
@@ -292,19 +292,19 @@ void LibView::drawEnvironmentInfo(Surface &dest, iXY pos)
 
     char strBuf[256];
 
-    dest.bltString(iXY(pos.x, pos.y), "-- Environment Info --", Color::green);
+    dest.bltString(pos.x, pos.y, "-- Environment Info --", Color::green);
     pos.y += yOffset;
 
     int windSpeed = gameconfig->windspeed;
     sprintf(strBuf, "Wind:   %s (%d pix/sec)",
             HostOptionsView::windSpeedString.c_str(), windSpeed);
-    dest.bltString(iXY(pos.x, pos.y), strBuf, Color::yellow);
+    dest.bltString(pos.x, pos.y, strBuf, Color::yellow);
     pos.y += yOffset;
 
     int cloudCount = gameconfig->cloudcoverage;
     sprintf(strBuf, "Clouds: %s (%d allocated)",
             HostOptionsView::cloudCoverageString.c_str(), cloudCount);
-    dest.bltString(iXY(pos.x, pos.y), strBuf, Color::yellow);
+    dest.bltString(pos.x, pos.y, strBuf, Color::yellow);
     pos.y += yOffset;
 
 } // end LibView::drawEnvironmentInfo
