@@ -25,6 +25,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "cMouse.hpp"
 #include "TerminalNetMesg.hpp"
 #include "Client.hpp"
+#include "NetworkClient.hpp"
 #include "NetworkState.hpp"
 #include "WorldInputCmdProcessor.hpp"
 #include "WorldViewInterface.hpp"
@@ -97,12 +98,11 @@ static void sendOutpostStatus()
                                     (char) vsvSelectedUnit,
                                     vsvUnitGenOn );
 
-    CLIENT->sendMessage( &term_mesg, sizeof(TerminalOutpostUnitGenRequest), 0 );
+    CLIENT->sendMessage(&term_mesg, sizeof(term_mesg));
 
-    if ( NetworkState::status == _network_state_client ) {
+    if(NetworkState::status == _network_state_client) {
         ObjectiveInterface::sendMessage( &(term_mesg.unit_gen_request) );
     }
-
 }
 
 static void bOK()
@@ -404,41 +404,41 @@ VehicleSelectionView::VehicleSelectionView() : GameTemplateView()
     buttonOk.setBounds(iRect(pos, pos + iXY(100, 15)));
     add(&buttonOk);
 
-    unitImages.create(48, 48, 48, _MAX_UNIT_TYPES);
+    unitImages.create(48, 48, _MAX_UNIT_TYPES);
 
     Surface tempSurface;
     int i = 0;
 
     tempSurface.loadBMP("pics/menus/vehicleSelectionView/manta.bmp");
     unitImages.setFrame(i++);
-    tempSurface.blt(unitImages);
+    tempSurface.blt(unitImages, 0, 0);
     tempSurface.loadBMP("pics/menus/vehicleSelectionView/panther1.bmp");
     unitImages.setFrame(i++);
-    tempSurface.blt(unitImages);
+    tempSurface.blt(unitImages, 0, 0);
     tempSurface.loadBMP("pics/menus/vehicleSelectionView/titan.bmp");
     unitImages.setFrame(i++);
-    tempSurface.blt(unitImages);
+    tempSurface.blt(unitImages, 0, 0);
     tempSurface.loadBMP("pics/menus/vehicleSelectionView/stinger.bmp");
     unitImages.setFrame(i++);
-    tempSurface.blt(unitImages);
+    tempSurface.blt(unitImages, 0, 0);
     tempSurface.loadBMP("pics/menus/vehicleSelectionView/bobcat.bmp");
     unitImages.setFrame(i++);
-    tempSurface.blt(unitImages);
+    tempSurface.blt(unitImages, 0, 0);
     tempSurface.loadBMP("pics/menus/vehicleSelectionView/bear.bmp");
     unitImages.setFrame(i++);
-    tempSurface.blt(unitImages);
+    tempSurface.blt(unitImages, 0, 0);
     tempSurface.loadBMP("pics/menus/vehicleSelectionView/archer.bmp");
     unitImages.setFrame(i++);
-    tempSurface.blt(unitImages);
+    tempSurface.blt(unitImages, 0, 0);
     tempSurface.loadBMP("pics/menus/vehicleSelectionView/wolf.bmp");
     unitImages.setFrame(i++);
-    tempSurface.blt(unitImages);
+    tempSurface.blt(unitImages, 0, 0);
     tempSurface.loadBMP("pics/menus/vehicleSelectionView/drake.bmp");
     unitImages.setFrame(i++);
-    tempSurface.blt(unitImages);
+    tempSurface.blt(unitImages, 0, 0);
     tempSurface.loadBMP("pics/menus/vehicleSelectionView/scout.bmp");
     unitImages.setFrame(i++);
-    tempSurface.blt(unitImages);
+    tempSurface.blt(unitImages, 0, 0);
     unitImages.setFrame(i++);
     unitImages.fill(Color::red);
     unitImages.setFrame(i++);
@@ -541,21 +541,30 @@ void VehicleSelectionView::doDraw(Surface &viewArea, Surface &clientArea)
 
     if (vsvUnitGenOn) {
         sprintf(strBuf, "%s", getUnitName(vsvSelectedUnit));
-        clientArea.bltString(productionUnitPos, strBuf, color);
+        clientArea.bltString(   productionUnitPos.x, productionUnitPos.y, 
+                                strBuf, color);
 
-        sprintf(strBuf, "%01d:%02d/%01d:%02d", ((int)outpost_status.unit_generation_time_remaining + 1) / 60, ((int)outpost_status.unit_generation_time_remaining) % 60, ((int)outpost_status.unit_generation_time) / 60, ((int)outpost_status.unit_generation_time + 1) % 60);
-        clientArea.bltString(timeRequiredPos, strBuf, color);
+        sprintf(strBuf, "%01d:%02d/%01d:%02d",
+                    ((int)outpost_status.unit_generation_time_remaining) / 60,
+                    ((int)outpost_status.unit_generation_time_remaining) % 60,
+                    ((int)outpost_status.unit_generation_time) / 60,
+                    ((int)outpost_status.unit_generation_time) % 60);
+         
+        clientArea.bltString(   timeRequiredPos.x, timeRequiredPos.y, 
+                                strBuf, color);
     } else {
         sprintf(strBuf, "power off");
-        clientArea.bltString(productionUnitPos, strBuf, color);
+        clientArea.bltString(   productionUnitPos.x, productionUnitPos.y, 
+                                strBuf, color);
 
         sprintf(strBuf, "power off");
-        clientArea.bltString(timeRequiredPos, strBuf, color);
+        clientArea.bltString(   timeRequiredPos.x, timeRequiredPos.y, 
+                                strBuf, color);
     }
 
     int unitPerPlayer = gameconfig->maxunits / gameconfig->maxplayers;
     sprintf(strBuf, "%d/%d", int(UnitInterface::getUnitCount(PlayerInterface::getLocalPlayerIndex())), unitPerPlayer);
-    clientArea.bltString(unitsBuiltPos, strBuf, color);
+    clientArea.bltString(unitsBuiltPos.x, unitsBuiltPos.y, strBuf, color);
 
     drawUnitProfileInfo(clientArea, iXY(0, unitProfileDataY), highlightedUnitType);
 
@@ -571,7 +580,7 @@ void VehicleSelectionView::doDraw(Surface &viewArea, Surface &clientArea)
 void VehicleSelectionView::drawUnitImage(Surface &dest, const iXY &pos, int unitType)
 {
     unitImages.setFrame(unitType);
-    unitImages.blt(dest, pos);
+    unitImages.blt(dest, pos.x, pos.y);
 
 } // end VehicleSelectionView::drawUnitImage
 
@@ -601,12 +610,6 @@ const char *VehicleSelectionView::getUnitName(int unitType)
         return "Drake";
     } else if (unitType == _unit_type_archer) {
         return "Archer";
-    } else if (unitType == _unit_type_hover_craft) {
-        return "Hovercraft";
-    } else if (unitType == _unit_type_comm_killer) {
-        return "Communications Killer";
-    } else if (unitType == _unit_type_refueler) {
-        return "Refueling truck";
     } else if (unitType == _unit_type_null) {
         return "None";
     } else {
@@ -713,15 +716,15 @@ void VehicleSelectionView::drawMiniProductionStatus(Surface &dest)
                     // Objective is off.
                     dest.bltLookup(miniProductionRect, Palette::darkGray256.getColorArray());
 
-                    dest.bltString(pos, outpostNameBuf, Color::white);
+                    dest.bltString(pos.x, pos.y, outpostNameBuf, Color::white);
                     pos.y += 16;
-                    dest.bltString(pos, "Production Off", Color::white);
+                    dest.bltString(pos.x, pos.y, "Production Off", Color::white);
 
                 } else {
                     // Objective is on.
 
                     iXY pos;
-                    pos.x = miniProductionRect.min.x + unitImages.getPixX() + 4;
+                    pos.x = miniProductionRect.min.x + unitImages.getWidth() + 4;
                     pos.y = miniProductionRect.min.y + 4;
 
                     // Make sure the name will fit reasonably in the area.
@@ -735,23 +738,25 @@ void VehicleSelectionView::drawMiniProductionStatus(Surface &dest)
                     }
                     checkMiniProductionRect(outpostNameBuf);
 
-                    sprintf(productionUnitBuf, "Production: %s", getUnitName(outpostStatus.unit_generation_type));
+                    sprintf(productionUnitBuf, "Production: %s",
+                            getUnitName(outpostStatus.unit_generation_type));
                     checkMiniProductionRect(productionUnitBuf);
 
                     sprintf(timeLeftBuf, "Time Left:  %01d:%02d",
-                            ((int)outpostStatus.unit_generation_time_remaining 
-                                + 1) / 60,
+                            ((int)outpostStatus.unit_generation_time_remaining)
+                                / 60,
                             ((int)outpostStatus.unit_generation_time_remaining)
                                 % 60);
                     checkMiniProductionRect(timeLeftBuf);
 
-                    dest.bltLookup(miniProductionRect, Palette::darkGray256.getColorArray());
+                    dest.bltLookup(miniProductionRect,
+                            Palette::darkGray256.getColorArray());
 
-                    dest.bltString(pos, outpostNameBuf, Color::white);
+                    dest.bltString(pos.x, pos.y, outpostNameBuf, Color::white);
                     pos.y += 16;
-                    dest.bltString(pos, productionUnitBuf, Color::white);
+                    dest.bltString(pos.x, pos.y, productionUnitBuf, Color::white);
                     pos.y += 16;
-                    dest.bltString(pos, timeLeftBuf, Color::white);
+                    dest.bltString(pos.x, pos.y, timeLeftBuf, Color::white);
                     pos.y += 16;
 
                     // Draw the current production unit image.
@@ -796,7 +801,7 @@ void VehicleSelectionView::drawMiniProductionStatus(Surface &dest)
 
                     dest.bltLookup(miniProductionRect, Palette::darkGray256.getColorArray());
 
-                    dest.bltString(pos, outpostNameBuf, Color::white);
+                    dest.bltString(pos.x, pos.y, outpostNameBuf, Color::white);
                 }
             }
             break;
@@ -830,7 +835,7 @@ void VehicleSelectionView::doActivate()
         pos = mouse.getScreenPos() - getSize() / 2;
 
         moveTo(pos);
-        checkArea(screen->getPix());
+        checkArea(iXY(screen->getWidth(),screen->getHeight()));
     }
 
     GameTemplateView::doActivate();
@@ -890,34 +895,29 @@ void VehicleSelectionView::drawUnitProfileInfo(Surface &dest, const iXY &pos, sh
     const int barOffset = 105;
     int       barLength = getClientRect().getSizeX() - barOffset;
 
-    dest.bltStringShadowed(loc, "Hit Points", Color::white, Color::black);
+    dest.bltStringShadowed(loc.x, loc.y, "Hit Points", Color::white, Color::black);
     drawBar(dest, iXY(loc.x + barOffset, loc.y), barLength, float(profile->hit_points) / float(maxHitPoints));
     loc.y += gapSpace;
 
-    dest.bltStringShadowed(loc, "Attack Power", Color::white, Color::black);
+    dest.bltStringShadowed(loc.x, loc.y, "Attack Power", Color::white, Color::black);
     drawBar(dest, iXY(loc.x + barOffset, loc.y), barLength, float(profile->attack_factor) / float(maxAttackFactor));
     loc.y += gapSpace;
 
-    dest.bltStringShadowed(loc, "Attack Range", Color::white, Color::black);
+    dest.bltStringShadowed(loc.x, loc.y, "Attack Range", Color::white, Color::black);
     drawBar(dest, iXY(loc.x + barOffset, loc.y), barLength, float(sqrt(profile->attack_range)) / float(maxAttackRange));
     loc.y += gapSpace;
 
-    dest.bltStringShadowed(loc, "Defend Range", Color::white, Color::black);
+    dest.bltStringShadowed(loc.x, loc.y, "Defend Range", Color::white, Color::black);
     drawBar(dest, iXY(loc.x + barOffset, loc.y), barLength, float(sqrt(profile->defend_range)) / float(maxDefendRange));
     loc.y += gapSpace;
 
-    dest.bltStringShadowed(loc, "Speed", Color::white, Color::black);
+    dest.bltStringShadowed(loc.x, loc.y, "Speed", Color::white, Color::black);
     drawBar(dest, iXY(loc.x + barOffset, loc.y), barLength, float(profile->speed_factor + profile->speed_rate) / float(maxTotalSpeed));
     loc.y += gapSpace;
 
-    dest.bltStringShadowed(loc, "Reload Time", Color::white, Color::black);
+    dest.bltStringShadowed(loc.x, loc.y, "Reload Time", Color::white, Color::black);
     drawBar(dest, iXY(loc.x + barOffset, loc.y), barLength, float(profile->reload_time) / float(maxReloadTime));
     loc.y += gapSpace;
-
-    dest.bltStringShadowed(loc, "Regen Time", Color::white, Color::black);
-    drawBar(dest, iXY(loc.x + barOffset, loc.y), barLength, float(profile->regen_time) / float(maxRegenTime));
-    loc.y += gapSpace;
-
 }
 
 void VehicleSelectionView::drawBar(Surface &dest, const iXY &pos, int length, float percent)
