@@ -32,6 +32,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "2D/Palette.hpp"
 #include "GameViewGlobals.hpp"
 #include "IPAddressView.hpp"
+#include "ServerListView.hpp"
+
 
 #include "Client.hpp"
 #include "Server.hpp"
@@ -90,6 +92,8 @@ static void bNext()
     if(gameconfig->hostorjoin == _game_session_join) {
         gameconfig->serverConnect = IPAddressView::szServer.getString();
     }
+    
+    serverlistview->endQuery();
 
     MenuTemplateView::backgroundSurface.free();
 
